@@ -21,6 +21,11 @@
 #include <fcntl.h>
 #include <sys/types.h>
 #include <sys/time.h>
+#include <sys/wait.h>
+
+#if defined __linux
+#include <getopt.h>
+#endif
 
 #include <signal.h>
 #include <errno.h>
@@ -28,13 +33,23 @@
 
 #include "../../fvwm/module.h"
 
-#define F_NAME  "/.FvwmCommand"
+#ifndef HAVE_STRERROR
+extern char *sys_errlist[];
+#define strerror(_e)    (sys_errlist[_e])
+#endif
+
+
+#define F_NAME  ".FvwmCommand"
 
 #define MAX_COMMAND_SIZE   768
 
-/* number of default arguments when invoked from fvwm */
+#define CMD_KILL_NOUNLINK "#@killme\n"
+#define CMD_CONNECT       "#@connect"
+#define CMD_EXIT          "#@exit\n"
+
+/* number of default arguments when invoked from fvwm2 */
 #define FARGS 6
 
 #define SOL  sizeof( unsigned long )
 
-#define MYVERSION "1.4"
+#define MYVERSION "1.5"
