@@ -44,7 +44,12 @@ Bool desperate;
  * find_func_type which is called from menus.c. Some work has to be done
  * before it can be removed.
  * Dominik Vogt 21/11/98
-
+ *
+ * My   mistake. However,  they  are  no  longer  used for their original
+ * purpose, and  the   use menus.c is  putting   them to  seems  somewhat
+ * unnecessary.  I'm  going to use  F_NOP for EdgeThickness,  and see
+ * how that goes.
+ * dje 12/19/98.
  */
 static struct functions func_config[] =
 {
@@ -80,9 +85,11 @@ static struct functions func_config[] =
   {"Current",      CurrentFunc,      F_CURRENT,             FUNC_NO_WINDOW},
   {"CursorMove",   movecursor,       F_MOVECURSOR,          FUNC_NO_WINDOW},
   {"CursorStyle",  CursorStyle,      F_CURSOR_STYLE,        FUNC_NO_WINDOW},
+  {"DefaultColors",SetDefaultColors, F_DFLT_COLORS,         FUNC_NO_WINDOW},
+  {"DefaultFont",  LoadDefaultFont,  F_DFLT_FONT,           FUNC_NO_WINDOW},
   {"Delete",       delete_function,  F_DELETE,              FUNC_NEEDS_WINDOW},
   {"Desk",         changeDesks_func, F_DESK,                FUNC_NO_WINDOW},
-  {"DesktopSize",  SetDeskSize,       F_SETDESK,            FUNC_NO_WINDOW},
+  {"DesktopSize",  SetDeskSize,      F_SETDESK,             FUNC_NO_WINDOW},
   {"Destroy",      destroy_function, F_DESTROY,             FUNC_NEEDS_WINDOW},
 #ifdef USEDECOR
   {"DestroyDecor", DestroyDecor,     F_DESTROY_DECOR,	    FUNC_NO_WINDOW},
@@ -95,6 +102,8 @@ static struct functions func_config[] =
   {"Echo",         echo_func,        F_ECHO,                FUNC_NO_WINDOW},
   {"EdgeResistance",SetEdgeResistance,F_EDGE_RES,           FUNC_NO_WINDOW},
   {"EdgeScroll",   SetEdgeScroll,    F_EDGE_SCROLL,         FUNC_NO_WINDOW},
+  {"EdgeThickness",setEdgeThickness, F_NOP,                 FUNC_NO_WINDOW},
+  {"Emulate",      Emulate,          F_EMULATE,             FUNC_NO_WINDOW},
   {"Exec",         exec_function,    F_EXEC,                FUNC_NO_WINDOW},
   {"ExecUseSHELL", exec_setup,       F_EXEC_SETUP,          FUNC_NO_WINDOW},
   {"FlipFocus",    flip_focus_func,  F_FLIP_FOCUS,          FUNC_NEEDS_WINDOW},
@@ -111,7 +120,7 @@ static struct functions func_config[] =
   {"Lower",        lower_function,   F_LOWER,               FUNC_NEEDS_WINDOW},
   {"Maximize",     Maximize,         F_MAXIMIZE,            FUNC_NEEDS_WINDOW},
   {"Menu",         staysup_func,     F_STAYSUP,             FUNC_POPUP},
-  {"MenuStyle",    SetMenuStyle1,    F_MENUSTYLE,           FUNC_NO_WINDOW},
+  {"MenuStyle",    OldMenuStyle,     F_MENUSTYLE,           FUNC_NO_WINDOW},
   {"Module",       executeModule,    F_MODULE,              FUNC_NO_WINDOW},
   {"ModulePath",   setModulePath,    F_MODULE_PATH,         FUNC_NO_WINDOW},
   {"Mouse",        ParseMouseEntry,  F_MOUSE,               FUNC_NO_WINDOW},
@@ -123,9 +132,7 @@ static struct functions func_config[] =
   {"Nop",          Nop_func,         F_NOP,                 FUNC_NOP},
   {"OpaqueMoveSize", SetOpaque,      F_OPAQUE,              FUNC_NO_WINDOW},
   {"PipeRead",     PipeRead,         F_READ,                FUNC_NO_WINDOW},
-#ifdef XPM
   {"PixmapPath",   setPixmapPath,    F_PIXMAP_PATH,         FUNC_NO_WINDOW},
-#endif /* XPM */
   {"PopUp",        popup_func,       F_POPUP,               FUNC_POPUP},
   {"Prev",         PrevFunc,         F_PREV,                FUNC_NO_WINDOW},
   {"Quit",         quit_func,        F_QUIT,                FUNC_NO_WINDOW},
@@ -145,8 +152,7 @@ static struct functions func_config[] =
   {"set_mask",     set_mask_function,F_SET_MASK,            FUNC_NO_WINDOW},
   {"SetAnimation", set_animation,    F_SET_ANIMATION,	    FUNC_NO_WINDOW},
   {"SetEnv",       SetEnv,           F_SETENV,              FUNC_NO_WINDOW},
-  {"SetMenuDelay", set_menudelay,    F_SET_MENUDELAY,	    FUNC_NO_WINDOW},
-  {"SetMenustyle", SetMenuStyle,     F_SET_MENUSTYLE,       FUNC_NO_WINDOW},
+  {"SetMenuStyle", SetMenuStyle,     F_SET_MENUSTYLE,       FUNC_NO_WINDOW},
   {"SnapAttraction",SetSnapAttraction,F_SNAP_ATT,           FUNC_NO_WINDOW},
   {"SnapGrid",     SetSnapGrid,      F_SNAP_GRID,           FUNC_NO_WINDOW},
   {"Stick",        stick_function,   F_STICK,               FUNC_NEEDS_WINDOW},
