@@ -16,6 +16,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <signal.h>
+#include <setjmp.h>
 #include <fcntl.h>
 #include <string.h>
 #include <unistd.h>
@@ -66,10 +67,10 @@ static int num_config_commands=0;
 char *output_file = NULL;
 #endif
 
-XErrorHandler FvwmErrorHandler(Display *, XErrorEvent *);
-XIOErrorHandler CatchFatal(Display *);
-XErrorHandler CatchRedirectError(Display *, XErrorEvent *);
-void newhandler(int sig);
+int FvwmErrorHandler(Display *, XErrorEvent *);
+int CatchFatal(Display *);
+int CatchRedirectError(Display *, XErrorEvent *);
+void newhandler(int sig, sigset_t mask);
 void CreateCursors(void);
 void ChildDied(int nonsense);
 void SaveDesktopState(void);
@@ -116,6 +117,12 @@ Bool Restarting = False;
 int fd_width, x_fd;
 char *display_name = NULL;
 
+typedef enum { FVWM_RUNNING=0, FVWM_DONE, FVWM_RESTART } FVWM_STATE;
+
+static FVWM_STATE    fvwmRunState = FVWM_RUNNING;
+static sig_atomic_t  canJump = False;
+static sigjmp_buf    deadjump;
+
 /***********************************************************************
  *
  *  Procedure:
@@ -136,6 +143,7 @@ int main(int argc, char **argv)
   char message[255];
   Bool single = False;
   Bool option_error = FALSE;
+  int x, y;
 
   g_argv = argv;
   g_argc = argc;
@@ -232,12 +240,43 @@ int main(int argc, char **argv)
 
   DBUG("main","Installing signal handlers");
 
-  newhandler (SIGINT);
-  newhandler (SIGHUP);
-  newhandler (SIGQUIT);
-  newhandler (SIGTERM);
-  signal (SIGUSR1, Restart);
-  signal (SIGPIPE, DeadPipe);
+  {
+    struct sigaction  sigact;
+
+    /*
+     * Use reliable signal semantics since they are predictable and portable.
+     */
+#ifdef SA_RESTART
+    sigact.sa_flags = SA_RESTART;
+#else
+    sigact.sa_flags = 0;
+#endif
+    sigemptyset(&sigact.sa_mask);
+
+    sigact.sa_handler = DeadPipe;  /* This handler does nothing ??? */
+    sigaction(SIGPIPE, &sigact, NULL);
+
+    /*
+     * The signals USR1, TERM, QUIT, HUP and INT are going to share some
+     * static variables so we must ensure that the handlers don't trip over
+     * each other. This signal mask will be installed while the process is in
+     * the signal handler, and will temporarily block delivery of the other
+     * four signals ...
+     */
+    sigaddset(&sigact.sa_mask, SIGUSR1);
+    sigaddset(&sigact.sa_mask, SIGTERM);
+    sigaddset(&sigact.sa_mask, SIGQUIT);
+    sigaddset(&sigact.sa_mask, SIGHUP);
+    sigaddset(&sigact.sa_mask, SIGINT);
+
+    sigact.sa_handler = Restart;
+    sigaction(SIGUSR1, &sigact, NULL);
+
+    newhandler(SIGINT,sigact.sa_mask);
+    newhandler(SIGHUP,sigact.sa_mask);
+    newhandler(SIGQUIT,sigact.sa_mask);
+    newhandler(SIGTERM,sigact.sa_mask);
+  }
 
   ReapChildren();
 
@@ -248,9 +287,6 @@ int main(int argc, char **argv)
   }
   Scr.screen= DefaultScreen(dpy);
   Scr.NumberOfScreens = ScreenCount(dpy);
-  Scr.DrawGC = 0;
-
-  Scr.DefaultMenuFace = NULL;
 
   master_pid = getpid();
 
@@ -353,8 +389,8 @@ int main(int argc, char **argv)
                    XA_CARDINAL, 32, PropModeReplace, NULL, 0);
 
 
-  XSetErrorHandler((XErrorHandler)CatchRedirectError);
-  XSetIOErrorHandler((XIOErrorHandler)CatchFatal);
+  XSetErrorHandler(CatchRedirectError);
+  XSetIOErrorHandler(CatchFatal);
   XSelectInput(dpy, Scr.Root,
                LeaveWindowMask| EnterWindowMask | PropertyChangeMask |
                SubstructureRedirectMask | KeyPressMask |
@@ -362,7 +398,7 @@ int main(int argc, char **argv)
                ButtonPressMask | ButtonReleaseMask );
   XSync(dpy, 0);
 
-  XSetErrorHandler((XErrorHandler)FvwmErrorHandler);
+  XSetErrorHandler(FvwmErrorHandler);
 
   BlackoutScreen(); /* if they want to hide the capture/startup */
 
@@ -398,13 +434,13 @@ int main(int argc, char **argv)
   {
     Scr.gray_pixmap =
       XCreatePixmapFromBitmapData(dpy,Scr.Root,g_bits, g_width,g_height,
-                                  Scr.DefaultMenuFace->MenuColors.fore,
-				  Scr.DefaultMenuFace->MenuColors.back,
+                                  Scr.StdColors.fore,
+				  Scr.StdColors.back,
                                   Scr.d_depth);
     Scr.light_gray_pixmap =
       XCreatePixmapFromBitmapData(dpy,Scr.Root,l_g_bits,l_g_width,l_g_height,
-                                  Scr.DefaultMenuFace->MenuColors.fore,
-				  Scr.DefaultMenuFace->MenuColors.back,
+                                  Scr.StdColors.fore,
+				  Scr.StdColors.back,
                                   Scr.d_depth);
   }
 
@@ -428,41 +464,32 @@ int main(int argc, char **argv)
 
   Scr.SizeStringWidth = XTextWidth (Scr.StdFont.font,
                                     " +8888 x +8888 ", 15);
-  attributes.border_pixel = Scr.DefaultMenuFace->MenuColors.fore;
-  attributes.background_pixel = Scr.DefaultMenuFace->MenuColors.back;
+  attributes.border_pixel = Scr.StdColors.fore;
+  attributes.background_pixel = Scr.StdColors.back;
   attributes.bit_gravity = NorthWestGravity;
   valuemask = (CWBorderPixel | CWBackPixel | CWBitGravity);
-  if(Scr.DefaultMenuFace->style != MWMMenu)
+  if(!Scr.gs.EmulateMWM)
   {
-    Scr.SizeWindow = XCreateWindow (dpy, Scr.Root,
-                                    0, 0,
-                                    (unsigned int)(Scr.SizeStringWidth +
-                                                   SIZE_HINDENT*2),
-                                    (unsigned int) (Scr.StdFont.height +
-                                                    SIZE_VINDENT*2),
-                                    (unsigned int) 0, 0,
-                                    (unsigned int) CopyFromParent,
-                                    (Visual *) CopyFromParent,
-                                    valuemask, &attributes);
+    x = 0;
+    y = 0;
   }
   else
   {
-    Scr.SizeWindow = XCreateWindow (dpy, Scr.Root,
-                                    Scr.MyDisplayWidth/2 -
-                                    (Scr.SizeStringWidth +
-                                     SIZE_HINDENT*2)/2,
-                                    Scr.MyDisplayHeight/2 -
-                                    (Scr.StdFont.height +
-                                     SIZE_VINDENT*2)/2,
-                                    (unsigned int)(Scr.SizeStringWidth +
-                                                   SIZE_HINDENT*2),
-                                    (unsigned int) (Scr.StdFont.height +
-                                                    SIZE_VINDENT*2),
-                                    (unsigned int) 0, 0,
-                                    (unsigned int) CopyFromParent,
-                                    (Visual *) CopyFromParent,
-                                    valuemask, &attributes);
+    x = Scr.MyDisplayWidth/2 - (Scr.SizeStringWidth + SIZE_HINDENT*2)/2;
+    y = Scr.MyDisplayHeight/2 - (Scr.StdFont.height + SIZE_VINDENT*2)/2;
   }
+  Scr.SizeWindow = XCreateWindow (dpy, Scr.Root, x, y,
+				  (unsigned int)(Scr.SizeStringWidth +
+						 SIZE_HINDENT*2),
+				  (unsigned int) (Scr.StdFont.height +
+						  SIZE_VINDENT*2),
+				  (unsigned int) 0, 0,
+				  (unsigned int) CopyFromParent,
+				  (Visual *) CopyFromParent,
+				  valuemask, &attributes);
+  if(Scr.SizeWindow != None)
+    XSetWindowBackground(dpy, Scr.SizeWindow, Scr.StdColors.back);
+
 #ifndef NON_VIRTUAL
   initPanFrames();
 #endif
@@ -480,8 +507,23 @@ int main(int argc, char **argv)
     Scr.ClickTime = -Scr.ClickTime;
   fFvwmInStartup = False;
   DBUG("main","Entering HandleEvents loop...");
-  HandleEvents();
-  DBUG("main","Back from HandleEvents loop?  Exitting...");
+
+  switch( (fvwmRunState = sigsetjmp(deadjump,1)) )
+  {
+  case FVWM_RUNNING:
+    canJump = True;
+    HandleEvents();    /* does not return */
+
+  case FVWM_DONE:
+    Done(0, NULL);     /* does not return */
+
+  case FVWM_RESTART:
+    Done(1, *g_argv);  /* does not return */
+
+  default:
+    DBUG("main","Unknown FVWM run-state");
+  }
+
   return 0;
 }
 
@@ -654,10 +696,10 @@ void SetRCDefaults()
   char *defaults[] = {
     "HilightColor black grey",
     "XORValue 0",
-    "SetMenuStyle default black grey slategrey white fixed noanim fvwm",
+    "DefaultFont fixed",
+    "DefaultColors black grey",
+    "SetMenuStyle * fvwm, Foreground black, Background grey, Greyed slategrey",
     "TitleStyle Centered -- Raised",
-    "IconFont fixed",
-    "WindowFont fixed",
     "Style \"*\" Color lightgrey/dimgrey, Title",
     "Style \"*\" RandomPlacement, SmartPlacement",
     "AddToMenu builtin_menu \"Builtin Menu\" Title",
@@ -790,13 +832,21 @@ void InternUsefulAtoms (void)
 /***********************************************************************
  *
  *  Procedure:
- *	newhandler: Installs new signal handler
+ *	newhandler: Installs new signal handler (reliable semantics)
  *
  ************************************************************************/
-void newhandler(int sig)
+void newhandler(int sig, sigset_t mask)
 {
-  if (signal (sig, SIG_IGN) != SIG_IGN)
-    signal (sig, SigDone);
+  struct sigaction  sigact;
+
+  sigaction(sig,NULL,&sigact);
+  if (sigact.sa_handler != SIG_IGN)
+  {
+    sigact.sa_mask = mask;
+    sigact.sa_flags = 0;
+    sigact.sa_handler = SigDone;
+    sigaction(sig,&sigact,NULL);
+  }
 }
 
 
@@ -805,8 +855,13 @@ void newhandler(int sig)
  ************************************************************************/
 RETSIGTYPE Restart(int nonsense)
 {
-  Done(1, *g_argv);
-  SIGNAL_RETURN;
+  if (canJump)
+  {
+    canJump = False;
+    siglongjmp(deadjump,FVWM_RESTART);
+  }
+
+  _exit(0);  /* Does NOT call the chain of exit procedures */
 }
 
 /***********************************************************************
@@ -1198,11 +1253,26 @@ void InitVariables(void)
 
   /* initialize some lists */
   Scr.AllBindings = NULL;
-  Scr.AllMenus = NULL;
   Scr.TheList = NULL;
 
+  Scr.menus.all = NULL;
+  Scr.menus.DefaultStyle = NULL;
+  Scr.menus.LastStyle = NULL;
+  Scr.menus.PopupDelay10ms = DEFAULT_POPUP_DELAY;
+  Scr.menus.DoubleClickTime = DEFAULT_MENU_CLICKTIME;
+
   Scr.DefaultIcon = NULL;
 
+  Scr.StdColors.fore = 0;
+  Scr.StdColors.back = 0;
+  Scr.StdRelief.fore = 0;
+  Scr.StdRelief.back = 0;
+  Scr.StdGC = 0;
+  Scr.StdReliefGC = 0;
+  Scr.StdShadowGC = 0;
+  Scr.DrawGC = 0;
+  Scr.hasIconFont = False;
+  Scr.hasWindowFont = False;
 
   /* create graphics contexts */
   CreateGCs();
@@ -1276,7 +1346,7 @@ void InitVariables(void)
   Scr.SnapGridY = 1;
   Scr.OpaqueSize = 5;
   /* ClickTime is set to the positive value upon entering the event loop. */
-  Scr.ClickTime = -150;
+  Scr.ClickTime = -DEFAULT_CLICKTIME;
   Scr.ColormapFocus = COLORMAP_FOLLOWS_MOUSE;
 
   /* set major operating modes */
@@ -1297,11 +1367,13 @@ void InitVariables(void)
   Scr.StipledTitles = False;
 
   /*  RBW - 11/02/1998    */
-  Scr.ModifyUSP                          =  True;
-  Scr.CaptureHonorsStartsOnPage          =  True;
-  Scr.RecaptureHonorsStartsOnPage        =  False;
-  Scr.ActivePlacementHonorsStartsOnPage  =  True;
+  Scr.go.ModifyUSP                          =  True;
+  Scr.go.CaptureHonorsStartsOnPage          =  True;
+  Scr.go.RecaptureHonorsStartsOnPage        =  False;
+  Scr.go.ActivePlacementHonorsStartsOnPage  =  True;
 
+  Scr.gs.EmulateMWM = False;
+  Scr.gs.EmulateWIN = False;
   /* Not the right place for this, should only be called once somewhere .. */
   InitPictureCMap(dpy,Scr.Root);
 
@@ -1342,14 +1414,19 @@ void Reborder(void)
 /***********************************************************************
  *
  *  Procedure:
- *	Done - cleanup and exit fvwm
+ *	Done - tells FVWM to clean up and exit
  *
  ***********************************************************************
  */
 RETSIGTYPE SigDone(int nonsense)
 {
-  Done(0, NULL);
-  SIGNAL_RETURN;
+  if (canJump)
+  {
+    canJump = False;
+    siglongjmp(deadjump,FVWM_DONE);
+  }
+
+  _exit(0);  /* Does NOT call the chain of exit-procedures */
 }
 
 void Done(int restart, char *command)
@@ -1416,11 +1493,11 @@ void Done(int restart, char *command)
   else
   {
     XCloseDisplay(dpy);
-    exit(0);
   }
+  exit(0);
 }
 
-XErrorHandler CatchRedirectError(Display *dpy, XErrorEvent *event)
+int CatchRedirectError(Display *dpy, XErrorEvent *event)
 {
   fvwm_msg(ERR,"CatchRedirectError","another WM is running");
   exit(1);
@@ -1432,7 +1509,7 @@ XErrorHandler CatchRedirectError(Display *dpy, XErrorEvent *event)
  *	CatchFatal - Shuts down if the server connection is lost
  *
  ************************************************************************/
-XIOErrorHandler CatchFatal(Display *dpy)
+int CatchFatal(Display *dpy)
 {
   /* No action is taken because usually this action is caused by someone
      using "xlogout" to be able to switch between multiple window managers
@@ -1447,7 +1524,7 @@ XIOErrorHandler CatchFatal(Display *dpy)
  *	FvwmErrorHandler - displays info on internal errors
  *
  ************************************************************************/
-XErrorHandler FvwmErrorHandler(Display *dpy, XErrorEvent *event)
+int FvwmErrorHandler(Display *dpy, XErrorEvent *event)
 {
   extern int last_event_type;
 
