@@ -1,6 +1,6 @@
 /****************************************************************************
- * This module is based on Twm, but has been siginificantly modified 
- * by Rob Nation 
+ * This module is based on Twm, but has been siginificantly modified
+ * by Rob Nation
  ****************************************************************************/
 /*****************************************************************************/
 /**       Copyright 1988 by Evans & Sutherland Computer Corporation,        **/
@@ -60,30 +60,34 @@
 
 typedef enum {
     /* menu types */
-    MWMMenu                   ,
-    FVWMMenu                  ,
-    WINMenu                   ,
+    SimpleMenu = 0,
 #ifdef GRADIENT_BUTTONS
-    HGradMenu                 ,
-    VGradMenu                 ,
-    DGradMenu                 ,
-    BGradMenu                 ,
+    HGradMenu,
+    VGradMenu,
+    DGradMenu,
+    BGradMenu,
 #endif
 #ifdef PIXMAP_BUTTONS
-    PixmapMenu                ,
-    TiledPixmapMenu           ,
+    PixmapMenu,
+    TiledPixmapMenu,
 #endif
     SolidMenu
     /* max button is 8 (0x8) */
-} MenuFaceStyle;
+} MenuFaceType;
 
+typedef struct MenuFeel {
+    struct
+    {
+      unsigned char Animated : 1;
+      unsigned char PrepopMenus : 1;
+      unsigned char TitleWarp : 1;
+    } f;
+    int PopupOffsetPercent;
+    int PopupOffsetAdd;
+} MenuFeel;
 
-#define MenuFaceTypeMask        0x0008
 
 typedef struct MenuFace {
-    char *name;
-    struct MenuFace *next;
-    MenuFaceStyle style;
     union {
 #ifdef PIXMAP_BUTTONS
         Picture *p;
@@ -96,8 +100,26 @@ typedef struct MenuFace {
         } grad;
 #endif
     } u;
+    MenuFaceType type;
+} MenuFace;
+
+typedef struct MenuLook {
+    MenuFace face;
+    struct
+    {
+      unsigned char Hilight : 1;
+      unsigned char hasActiveFore : 1;
+      unsigned char hasActiveBack : 1;
+      unsigned char hasStippleFore : 1;
+      unsigned char hasFont : 1;
+      unsigned char LongSeparators : 1;
+      unsigned char TriangleRelief : 1;
+    } f;
+    char ReliefThickness;
+    char TitleUnderlines;
     GC MenuGC;
     GC MenuActiveGC;
+    GC MenuActiveBackGC;
     GC MenuStippleGC;
     GC MenuReliefGC;
     GC MenuShadowGC;
@@ -105,10 +127,16 @@ typedef struct MenuFace {
     ColorPair MenuActiveColors;
     ColorPair MenuStippleColors;
     ColorPair MenuRelief;
-    MyFont StdFont;
-    int EntryHeight;
-    char animated;
-} MenuFace;
+    MyFont *pStdFont;
+    int EntryHeight;              /* menu entry height */
+} MenuLook;
+
+typedef struct MenuStyle {
+    char *name;
+    struct MenuStyle *next;
+    MenuLook look;
+    MenuFeel feel;
+} MenuStyle;
 
 struct MenuRoot; /* forward declaration */
 
@@ -148,6 +176,13 @@ typedef struct MenuRoot
     MenuItem *first;	/* first item in menu */
     MenuItem *last;	/* last item in menu */
     MenuItem *selected;	/* the selected item in menu */
+#ifdef GRADIENT_BUTTONS
+    struct
+    {
+      XImage *image; /* storage pointer for selected item */
+      int y;
+    } stored_item;
+#endif
 
     struct MenuRoot *next;	/* next in list of root menus */
     struct MenuRoot *continuation; /* continuation of this menu
@@ -169,21 +204,44 @@ typedef struct MenuRoot
     Pixel sideColor;
     Bool colorize;
     short xoffset;
-    MenuFace        *mf;        /* Menu Face    */
-    unsigned char flags; /* internal flags, deleted when menu pops down! */
+    MenuStyle *ms;        /* Menu Face    */
+    union                 /* internal flags, deleted when menu pops down! */
+    {
+      /* need to change that type if we have more than 8 flags.
+       * more that a word will entail some changes in the code! */
+      unsigned char allflags;
+      struct
+      {
+#ifdef GRADIENT_BUTTONS
+	unsigned painted : 1;
+#endif
+	unsigned is_left : 1;   /* menu direction relative to parent menu */
+	unsigned is_right : 1;
+	unsigned is_up : 1;
+	unsigned is_down : 1;
+      } f;
+    } flags;
     int xanimation;      /* x distance window was moved by animation     */
 } MenuRoot;
 /* don't forget to initialise new members in NewMenuRoot()! */
 
+typedef struct MenuGlobals {
+    MenuRoot *all;
+    struct MenuStyle *DefaultStyle;
+    struct MenuStyle *LastStyle;
+    int PopupDelay10ms;
+    int DoubleClickTime;
+} MenuGlobals;
+
 typedef struct Binding
 {
   char IsMouse;           /* Is it a mouse or key binding 1= mouse; */
   int Button_Key;         /* Mouse Button number of Keycode */
   char *key_name;         /* In case of keycode, give the key_name too */
   int Context;            /* Contex is Fvwm context, ie titlebar, frame, etc */
-  int Modifier;           /* Modifiers for keyboard state */   
+  int Modifier;           /* Modifiers for keyboard state */
   char *Action;           /* What to do? */
-  struct Binding *NextBinding; 
+  struct Binding *NextBinding;
 } Binding;
 
 typedef struct
@@ -198,17 +256,23 @@ typedef struct
 typedef struct
 {
   MenuPosHints pos_hints;
-  unsigned char flags;
+  union
+  {
+    /* need to change that type if we have more than 8 flags.
+     * more that a word will entail some changes in the code! */
+    unsigned char allflags;
+    struct
+    {
+      unsigned no_warp : 1;
+      unsigned warp_title : 1;
+      unsigned fixed : 1;
+      unsigned select_in_place : 1;
+      unsigned select_warp : 1;
+      unsigned has_poshints : 1;
+    } f;
+  } flags;
 } MenuOptions;
 
-/* menu options flags */
-#define MENU_NOWARP           0x01
-#define MENU_WARPTITLE        0x02
-#define MENU_FIXED            0x04
-#define MENU_SELECTINPLACE    0x08
-#define MENU_SELECTWARP       0x10
-#define MENU_HAS_POSHINTS     0x20
-
 extern MenuPosHints lastMenuPosHints;
 extern Bool fLastMenuPosHintsValid;
 
@@ -219,9 +283,9 @@ extern Bool fLastMenuPosHintsValid;
 /* This is a lame hack, in that "_BUTTON" is added to mean a button-release
    caused the return-- the macros below help deal with the ugliness */
 typedef enum {
-    MENU_ERROR = -1, 
-    MENU_NOP = 0, 
-    MENU_DONE = 1, 
+    MENU_ERROR = -1,
+    MENU_NOP = 0,
+    MENU_DONE = 1,
     MENU_DONE_BUTTON = 2,  /* must be MENU_DONE + 1 */
     MENU_ABORTED = 3,
     MENU_ABORTED_BUTTON = 4, /* must be MENU_ABORTED + 1 */
@@ -238,19 +302,6 @@ typedef enum {
 #define MENU_ADD_BUTTON(x) ((x)==MENU_DONE || (x)==MENU_ABORTED?(x)+1:(x))
 #define MENU_ADD_BUTTON_IF(y,x) (y?MENU_ADD_BUTTON((x)):(x))
 
-#define USING_MWM_MENUS(menu)	((menu)->MenuFace->style == MWMMenu)
-#define USING_FVWM_MENUS(menu)	((menu)->MenuFace->style == FVWMMenu)
-#define USING_WIN_MENUS(menu)	((menu)->MenuFace->style == WINMenu)
-#define USING_NEXT_MENUS(menu)	((menu)->MenuFace->style >  WINMenu)
-
-/*
-#define USING_MWM_MENUS (Scr.menu_type == MWM)
-#define USING_WIN_MENUS (Scr.menu_type == WIN)
-#define USING_FVWM_MENUS (Scr.menu_type == FVWM)
-#define USING_PREPOP_MENUS (Scr.menu_type == MWM || Scr.menu_type == WIN)
-#define USING_ANIMATED_MENUS (Scr.flags & AnimatedMenus)
-*/
-
 /* Types of events for the FUNCTION builtin */
 #define MOTION 'm'
 #define IMMEDIATE 'i'
@@ -264,4 +315,4 @@ void AnimatedMoveOfWindow(Window w,int startX,int startY,int endX, int endY,
 			  float *ppctMovement );
 
 #endif /* _MENUS_ */
- 
+
