@@ -272,8 +272,8 @@ static void DoSnapAttract(FvwmWindow *tmp_win, int Width, int Height,
     }
   else
     {
-      self.w = Width + tmp_win->bw;
-      self.h = Height + tmp_win->bw;
+      self.w = Width + 2 * tmp_win->bw;
+      self.h = Height + 2 * tmp_win->bw;
     }
   while(Scr.SnapAttraction >= 0 && tmp)
     {
@@ -416,6 +416,7 @@ void moveLoop(FvwmWindow *tmp_win, int XOffset, int YOffset, int Width,
   Bool done;
   int xl,yt,delta_x,delta_y,paged;
   unsigned int button_mask = 0;
+  unsigned int bw = tmp_win->bw;
 
   XQueryPointer(dpy, Scr.Root, &JunkRoot, &JunkChild,&xl, &yt,
 		&JunkX, &JunkY, &button_mask);
@@ -423,10 +424,10 @@ void moveLoop(FvwmWindow *tmp_win, int XOffset, int YOffset, int Width,
   xl += XOffset;
   yt += YOffset;
 
-  if(((!opaque_move)&&(Scr.DefaultMenuFace->style!=MWMMenu))||(AddWindow))
-    MoveOutline(Scr.Root, xl, yt, Width,Height);
+  if(((!opaque_move)&&(!Scr.gs.EmulateMWM))||(AddWindow))
+    MoveOutline(Scr.Root, xl, yt, Width - 1 + 2 * bw, Height - 1 + 2 * bw);
 
-  DisplayPosition(tmp_win,xl+Scr.Vx,yt+Scr.Vy,True);
+  DisplayPosition(tmp_win,xl,yt,True);
 
   while (!finished)
     {
@@ -477,8 +478,8 @@ void moveLoop(FvwmWindow *tmp_win, int XOffset, int YOffset, int Width,
 	      done = 1;
 	      break;
 	    }
-	  if(((Event.xbutton.button == 2)&&(Scr.DefaultMenuFace != MWMMenu))||
-	     ((Event.xbutton.button == 1)&&(Scr.DefaultMenuFace == MWMMenu)&&
+	  if(((Event.xbutton.button == 2)&&(!Scr.gs.EmulateMWM))||
+	     ((Event.xbutton.button == 1)&&(Scr.gs.EmulateMWM)&&
 	      (Event.xbutton.state & ShiftMask)))
 	    {
 	      NeedToResizeToo = True;
@@ -513,12 +514,12 @@ void moveLoop(FvwmWindow *tmp_win, int XOffset, int YOffset, int Width,
 	  /* Resist moving windows over the edge of the screen! */
 	  if(((xl + Width) >= Scr.MyDisplayWidth)&&
 	     ((xl + Width) < Scr.MyDisplayWidth+Scr.MoveResistance))
-	    xl = Scr.MyDisplayWidth - Width - tmp_win->bw;
+	    xl = Scr.MyDisplayWidth - Width - 2 * bw;
 	  if((xl <= 0)&&(xl > -Scr.MoveResistance))
 	    xl = 0;
 	  if(((yt + Height) >= Scr.MyDisplayHeight)&&
 	     ((yt + Height) < Scr.MyDisplayHeight+Scr.MoveResistance))
-	    yt = Scr.MyDisplayHeight - Height - tmp_win->bw;
+	    yt = Scr.MyDisplayHeight - Height - 2 * bw;
 	  if((yt <= 0)&&(yt > -Scr.MoveResistance))
 	    yt = 0;
 
@@ -543,12 +544,12 @@ void moveLoop(FvwmWindow *tmp_win, int XOffset, int YOffset, int Width,
 	  /* Resist moving windows over the edge of the screen! */
 	  if(((xl + Width) >= Scr.MyDisplayWidth)&&
 	     ((xl + Width) < Scr.MyDisplayWidth+Scr.MoveResistance))
-	    xl = Scr.MyDisplayWidth - Width - tmp_win->bw;
+	    xl = Scr.MyDisplayWidth - Width - 2 * bw;
 	  if((xl <= 0)&&(xl > -Scr.MoveResistance))
 	    xl = 0;
 	  if(((yt + Height) >= Scr.MyDisplayHeight)&&
 	     ((yt + Height) < Scr.MyDisplayHeight+Scr.MoveResistance))
-	    yt = Scr.MyDisplayHeight - Height - tmp_win->bw;
+	    yt = Scr.MyDisplayHeight - Height - 2 * bw;
 	  if((yt <= 0)&&(yt > -Scr.MoveResistance))
 	    yt = 0;
 
@@ -558,7 +559,7 @@ void moveLoop(FvwmWindow *tmp_win, int XOffset, int YOffset, int Width,
 	  while(paged<=1)
 	    {
 	      if(!opaque_move)
-		MoveOutline(Scr.Root, xl, yt, Width,Height);
+		MoveOutline(Scr.Root, xl, yt, Width - 1 + 2 * bw, Height - 1 + 2 * bw);
 	      else
 		{
 		  if (tmp_win->flags & ICONIFIED)
@@ -578,20 +579,19 @@ void moveLoop(FvwmWindow *tmp_win, int XOffset, int YOffset, int Width,
 		  else
 		    XMoveWindow(dpy,tmp_win->frame,xl,yt);
 		}
-	      DisplayPosition(tmp_win,xl+Scr.Vx,yt+Scr.Vy,False);
+	      DisplayPosition(tmp_win,xl,yt,False);
 
 	      /* prevent window from lagging behind mouse when paging - mab */
 	      if(paged==0)
 		{
+		  int dx;
+		  int dy;
+
 		  xl = Event.xmotion.x_root;
 		  yt = Event.xmotion.y_root;
-#if 0
-		  HandlePaging(Scr.MyDisplayWidth,Scr.MyDisplayHeight,&xl,&yt,
-			       &delta_x,&delta_y,False);
-#else /* probably should actually use EdgeScroll values: */
-		  HandlePaging(Scr.EdgeScrollX,Scr.EdgeScrollY,&xl,&yt,
-			       &delta_x,&delta_y,False);
-#endif
+		  dx = Scr.EdgeScrollX ? Scr.EdgeScrollX : Scr.MyDisplayWidth;
+		  dy = Scr.EdgeScrollY ? Scr.EdgeScrollY : Scr.MyDisplayHeight;
+		  HandlePaging(dx, dy, &xl,&yt, &delta_x,&delta_y,False);
 		  xl += XOffset;
 		  yt += YOffset;
 		  if ( (delta_x==0) && (delta_y==0))
@@ -613,7 +613,7 @@ void moveLoop(FvwmWindow *tmp_win, int XOffset, int YOffset, int Width,
 	    MoveOutline(Scr.Root,0,0,0,0);
 	  DispatchEvent();
 	  if(!opaque_move)
-	    MoveOutline(Scr.Root, xl, yt, Width, Height);
+	    MoveOutline(Scr.Root, xl, yt, Width - 1 + 2 * bw, Height - 1 + 2 * bw);
 	}
     }
   if (!NeedToResizeToo)
@@ -646,8 +646,8 @@ void DisplayPosition (FvwmWindow *tmp_win, int x, int y,int Init)
 	RelieveWindow(tmp_win,Scr.SizeWindow,0,0,
 		      Scr.SizeStringWidth+ SIZE_HINDENT*2,
 		      Scr.StdFont.height + SIZE_VINDENT*2,
-		      Scr.DefaultMenuFace->MenuReliefGC,
-		      Scr.DefaultMenuFace->MenuShadowGC, FULL_HILITE);
+		      Scr.StdReliefGC,
+		      Scr.StdShadowGC, FULL_HILITE);
 
     }
   else
@@ -658,7 +658,7 @@ void DisplayPosition (FvwmWindow *tmp_win, int x, int y,int Init)
 
   offset = (Scr.SizeStringWidth + SIZE_HINDENT*2
 	    - XTextWidth(Scr.StdFont.font,str,strlen(str)))/2;
-  XDrawString (dpy, Scr.SizeWindow, Scr.DefaultMenuFace->MenuGC,
+  XDrawString (dpy, Scr.SizeWindow, Scr.StdGC,
 	       offset,
 	       Scr.StdFont.font->ascent + SIZE_VINDENT,
 	       str, strlen(str));
@@ -816,8 +816,6 @@ void InteractiveMove(Window *win, FvwmWindow *tmp_win, int *FinalX, int *FinalY,
   if((!opaque_move)&&(tmp_win->flags & ICONIFIED))
     XUnmapWindow(dpy,w);
 
-  DragWidth += JunkBW;
-  DragHeight+= JunkBW;
   XOffset = origDragX - DragX;
   YOffset = origDragY - DragY;
   XMapRaised(dpy,Scr.SizeWindow);
