@@ -406,21 +406,23 @@ Bool PlaceWindow(FvwmWindow *tmp_win, unsigned long tflag,int Desk, int PageX, i
           Honor the flag unless...
           it's a restart or recapture, and that option's disallowed...
       */
-      if (PPosOverride && (Restarting || (Scr.flags & WindowsCaptured)) && !Scr.RecaptureHonorsStartsOnPage)
+      if (PPosOverride && (Restarting || (Scr.flags & WindowsCaptured)) &&
+	  !Scr.go.RecaptureHonorsStartsOnPage)
         {
           HonorStartsOnPage  =  False;
         }
      /*
           it's a cold start window capture, and that's disallowed...
       */
-      if (PPosOverride && (!Restarting && !(Scr.flags & WindowsCaptured)) && !Scr.CaptureHonorsStartsOnPage)
+      if (PPosOverride && (!Restarting && !(Scr.flags & WindowsCaptured)) &&
+	  !Scr.go.CaptureHonorsStartsOnPage)
         {
           HonorStartsOnPage  =  False;
         }
       /*
           we have a USPosition, and overriding it is disallowed...
       */
-      if (!PPosOverride && (USPosition && !Scr.ModifyUSP))
+      if (!PPosOverride && (USPosition && !Scr.go.ModifyUSP))
         {
           HonorStartsOnPage  =  False;
         }
@@ -428,7 +430,8 @@ Bool PlaceWindow(FvwmWindow *tmp_win, unsigned long tflag,int Desk, int PageX, i
           it's ActivePlacement and SkipMapping, and that's disallowed.
       */
       if (!PPosOverride && ((tmp_win->flags & SHOW_ON_MAP) &&
-          (!(tflag & RANDOM_PLACE_FLAG)) && !Scr.ActivePlacementHonorsStartsOnPage))
+          (!(tflag & RANDOM_PLACE_FLAG)) &&
+			    !Scr.go.ActivePlacementHonorsStartsOnPage))
         {
           HonorStartsOnPage  =  False;
         }
@@ -541,10 +544,8 @@ Bool PlaceWindow(FvwmWindow *tmp_win, unsigned long tflag,int Desk, int PageX, i
       !(tmp_win->hints.flags & USPosition) &&
       ((tflag & NO_PPOSITION_FLAG)||
        !(tmp_win->hints.flags & PPosition)) &&
-      !(PPosOverride) &&
-      !((tmp_win->wmhints)&&
-	(tmp_win->wmhints->flags & StateHint)&&
-	(tmp_win->wmhints->initial_state == IconicState)) )
+      !(PPosOverride) )
+/*  RBW - removed check for IconicState hint - it hindered StartsOnPage.  */
   {
     /* Get user's window placement, unless RandomPlacement is specified */
     if(tflag & RANDOM_PLACE_FLAG)
@@ -661,11 +662,8 @@ Bool PlaceWindow(FvwmWindow *tmp_win, unsigned long tflag,int Desk, int PageX, i
            ( !(tmp_win->flags & TRANSIENT) &&
 
              ((tflag & NO_PPOSITION_FLAG) ||
-              !(tmp_win->hints.flags & PPosition)) &&
-
-             !((tmp_win->wmhints) &&
-               (tmp_win->wmhints->flags & StateHint) &&
-               (tmp_win->wmhints->initial_state == IconicState)) ) )
+              !(tmp_win->hints.flags & PPosition)) ) )
+/*  RBW - removed check for IconicState hint - it hindered StartsOnPage.  */
         {
         /*
             We're placing a SkipMapping window - either capturing one that's
