@@ -176,8 +176,8 @@ void resize_window(XEvent *eventp,Window w,FvwmWindow *tmp_win,
     }
   /* draw the rubber-band window */
   MoveOutline (Scr.Root, drag->x - tmp_win->bw, drag->y - tmp_win->bw,
-	       drag->width + 2 * tmp_win->bw,
-	       drag->height + 2 * tmp_win->bw);
+	       drag->width - 1 + 2 * tmp_win->bw,
+	       drag->height - 1 + 2 * tmp_win->bw);
   /* kick off resizing without requiring any motion if invoked with a key press */
   if (eventp->type == KeyPress)
     {
@@ -277,8 +277,8 @@ void resize_window(XEvent *eventp,Window w,FvwmWindow *tmp_win,
 	  MoveOutline(Scr.Root,0,0,0,0);
 	  DispatchEvent();
 	  MoveOutline(Scr.Root, drag->x - tmp_win->bw, drag->y - tmp_win->bw,
-		      drag->width + 2 * tmp_win->bw,
-		      drag->height + 2 * tmp_win->bw);
+		      drag->width - 1 + 2 * tmp_win->bw,
+		      drag->height - 1 + 2 * tmp_win->bw);
 
 	}
     }
@@ -377,8 +377,8 @@ static void DoResize(int x_root, int y_root, FvwmWindow *tmp_win,
 	drag->y = orig->y + orig->height - drag->height;
 
       MoveOutline(Scr.Root, drag->x - tmp_win->bw,drag->y - tmp_win->bw,
-		  drag->width + 2 * tmp_win->bw,
-		  drag->height + 2 * tmp_win->bw);
+		  drag->width - 1 + 2 * tmp_win->bw,
+		  drag->height - 1 + 2 * tmp_win->bw);
     }
   DisplaySize(tmp_win, drag->width, drag->height,False,False);
 }
@@ -433,8 +433,8 @@ void DisplaySize(FvwmWindow *tmp_win, int width, int height, Bool Init,
 	RelieveWindow(tmp_win,
 		      Scr.SizeWindow,0,0,Scr.SizeStringWidth+ SIZE_HINDENT*2,
 		      Scr.StdFont.height + SIZE_VINDENT*2,
-		      Scr.DefaultMenuFace->MenuReliefGC,
-		      Scr.DefaultMenuFace->MenuShadowGC,FULL_HILITE);
+		      Scr.StdReliefGC,
+		      Scr.StdShadowGC,FULL_HILITE);
     }
   else
     {
@@ -442,9 +442,8 @@ void DisplaySize(FvwmWindow *tmp_win, int width, int height, Bool Init,
 		 Scr.SizeStringWidth, Scr.StdFont.height,False);
     }
 
-  XDrawString (dpy, Scr.SizeWindow, Scr.DefaultMenuFace->MenuGC,
+  XDrawString (dpy, Scr.SizeWindow, Scr.StdGC,
 	       offset, Scr.StdFont.font->ascent + SIZE_VINDENT, str, 13);
-
 }
 
 /***********************************************************************
