@@ -1,16 +1,20 @@
 /*
 ** Module.c: code for modules to communicate with fvwm
 */
+#include "config.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <ctype.h>
 
+#include <errno.h>
+
 #include "fvwmlib.h"
 #include "../fvwm/module.h"
 
 
 /************************************************************************
- * 
+ *
  * Reads a single packet of info from fvwm. Prototype is:
  * unsigned long header[HEADER_SIZE];
  * unsigned long *body;
@@ -23,7 +27,7 @@
  *   > 0 everything is OK.
  *   = 0 invalid packet.
  *   < 0 pipe is dead. (Should never occur)
- *   body is a malloc'ed space which needs to be freed 
+ *   body is a malloc'ed space which needs to be freed
  *
  **************************************************************************/
 int ReadFvwmPacket(int fd, unsigned long *header, unsigned long **body)
@@ -32,6 +36,7 @@ int ReadFvwmPacket(int fd, unsigned long *header, unsigned long **body)
   char *cbody;
   extern void DeadPipe(int);
 
+  errno = 0;
   if((count = read(fd,header,HEADER_SIZE*sizeof(unsigned long))) >0)
   {
     if(header[0] == START_FLAG)
@@ -43,6 +48,7 @@ int ReadFvwmPacket(int fd, unsigned long *header, unsigned long **body)
       total = 0;
       while(total < body_length*sizeof(unsigned long))
       {
+        errno = 0;
         if((count2=
             read(fd,&cbody[total],
                  body_length*sizeof(unsigned long)-total)) >0)
@@ -51,7 +57,7 @@ int ReadFvwmPacket(int fd, unsigned long *header, unsigned long **body)
         }
         else if(count2 < 0)
         {
-          DeadPipe(1);
+          DeadPipe(errno);
         }
       }
     }
@@ -59,7 +65,7 @@ int ReadFvwmPacket(int fd, unsigned long *header, unsigned long **body)
       count = 0;
   }
   if(count <= 0)
-    DeadPipe(1);
+    DeadPipe(errno);
   return count;
 }
 
@@ -71,7 +77,7 @@ int ReadFvwmPacket(int fd, unsigned long *header, unsigned long **body)
 void SendText(int *fd,char *message,unsigned long window)
 {
   int w;
-  
+
   if(message != NULL)
   {
     write(fd[0],&window, sizeof(unsigned long));
@@ -87,8 +93,8 @@ void SendText(int *fd,char *message,unsigned long window)
 }
 
 /***************************************************************************
- * 
- * Sets the which-message-types-do-I-want mask for modules 
+ *
+ * Sets the which-message-types-do-I-want mask for modules
  *
  **************************************************************************/
 void SetMessageMask(int *fd, unsigned long mask)
@@ -100,7 +106,7 @@ void SetMessageMask(int *fd, unsigned long mask)
 }
 
 /***************************************************************************
- * Gets a module configuration line from fvwm. Returns NULL if there are 
+ * Gets a module configuration line from fvwm. Returns NULL if there are
  * no more lines to be had. "line" is a pointer to a char *.
  *
  * Changed 10/19/98 by Dan Espen:
@@ -129,13 +135,13 @@ void GetConfigLine(int *fd, char **tline)
   while(!done)
   {
     count = ReadFvwmPacket(fd[1],header,(unsigned long **)&line);
-    if(count > 0) {
-      *tline = &line[3*sizeof(long)];
-    } else {
+    /* DB(("Packet count is %d", count)); */
+    if (count <= 0)
       *tline = NULL;
-    }
-    if(*tline != NULL) {
+    else {
+      *tline = &line[3*sizeof(long)];
       body_size = header[2]-HEADER_SIZE;
+      /* DB(("Config line (%d): `%s'", body_size, body_size ? *tline : "")); */
       while((body_size > 0)
             && isspace(**tline)) {
         (*tline)++;
