@@ -11,7 +11,7 @@
   Some of the logic comes from pixy2, so the copyright is below.
   */
 /*
- * $Id: Picture.c,v 1.6 1998/11/06 23:27:05 psmith Exp $
+ * $Id: Picture.c,v 1.11 1998/11/15 18:00:11 dane Exp $
  * Copyright 1996, Romano Giannetti. No guarantees or warantees or anything
  * are provided or implied in any way whatsoever. Use this program at your
  * own risk. Permission to use this program for any purpose is given,
@@ -24,7 +24,6 @@
  *
  */
 
-
 /****************************************************************************
  *
  * Routines to handle initialization, loading, and removing of xpm's or mono-
@@ -59,14 +58,14 @@ static double c400_distance(XColor *, XColor *); /* prototype */
 
 
 static Picture *PictureList=NULL;
-static Colormap PictureCMap;
-static Display *save_dpy;               /* Save area for display pointer */
+Colormap PictureCMap;
+Display *PictureSaveDisplay;            /* Save area for display pointer */
 
-/* This routine called during fvwm initialization */
+/* This routine called during fvwm and some modules initialization */
 void InitPictureCMap(Display *dpy,Window Root)
 {
   XWindowAttributes root_attr;
-  save_dpy = dpy;                       /* save for latter */
+  PictureSaveDisplay = dpy;                       /* save for latter */
   XGetWindowAttributes(dpy,Root,&root_attr);
   PictureCMap=root_attr.colormap;
 }
@@ -79,7 +78,7 @@ Picture *LoadPicture(Display *dpy,Window Root,char *path, int color_limit)
 #ifdef XPM
   XpmAttributes xpm_attributes;
   int rc;
-  XpmImage	my_image;
+  XpmImage	my_image = {0};
 #endif
 
   p=(Picture*)safemalloc(sizeof(Picture));
@@ -120,7 +119,6 @@ Picture *LoadPicture(Display *dpy,Window Root,char *path, int color_limit)
       return p;
     }
 
-  free(path);
   free(p);
   return NULL;
 }
@@ -129,14 +127,18 @@ Picture *GetPicture(Display *dpy,Window Root,char *IconPath,char *PixmapPath,
 		    char *name, int color_limit)
 {
   char *path;
+  Picture *p;
+
   if(!(path=findIconFile(name,PixmapPath,R_OK)))
     if(!(path=findIconFile(name,IconPath,R_OK)))
       return NULL;
-  return LoadPicture(dpy,Root,path, color_limit);
+  p = LoadPicture(dpy,Root,path, color_limit);
+  free(path);
+  return p;
 }
 
 Picture *CachePicture(Display *dpy,Window Root,char *IconPath,char *PixmapPath,
-		    char *name, int color_limit)
+		      char *name, int color_limit)
 {
   char *path;
   Picture *p=PictureList;
@@ -158,8 +160,8 @@ Picture *CachePicture(Display *dpy,Window Root,char *IconPath,char *PixmapPath,
       if(!*p1 && !*p2) /* We have found a picture with the wanted name */
 	{
 	  p->count++; /* Put another weight on the picture */
-          free(path);
-          return p;
+	  free(path);
+	  return p;
 	}
       p=p->next;
     }
@@ -171,6 +173,8 @@ Picture *CachePicture(Display *dpy,Window Root,char *IconPath,char *PixmapPath,
       p->next=PictureList;
       PictureList=p;
     }
+  else
+    free(path);
   return p;
 }
 
@@ -218,29 +222,18 @@ char *findIconFile(char *icon, char *pathlist, int type)
 {
   char *path;
   char *dir_end;
-  int l1,l2;
+  int l;
 
-  if(icon != NULL)
-    l1 = strlen(icon);
-  else
-    l1 = 0;
+  if (!icon)
+    return NULL;
 
-  if(pathlist != NULL)
-    l2 = strlen(pathlist);
-  else
-    l2 = 0;
+  l = (pathlist) ? strlen(pathlist) : 0;
 
-  path = safemalloc(l1 + l2 + 10);
+  path = safemalloc(strlen(icon) + l + 10);
   *path = '\0';
-  if (*icon == '/')
+  if (*icon == '/' || pathlist == NULL || *pathlist == '\0') 
     {
       /* No search if icon begins with a slash */
-      strcpy(path, icon);
-      return path;
-    }
-
-  if ((pathlist == NULL) || (*pathlist == '\0'))
-    {
       /* No search if pathlist is empty */
       strcpy(path, icon);
       return path;
@@ -422,13 +415,15 @@ void c200_substitute_color(char **my_color, int color_limit) {
     }                                 /* end new low distance */
   }                                   /* end all base colors */
   /* Finally: replace the color string by the newly determined color string */
-  *my_color = base_array[minind].c_color; /* change the color */
+  free(*my_color);                      /* free old color */
+  *my_color = safemalloc(strlen(base_array[minind].c_color) + 1); /* area for new color */
+  strcpy(*my_color,base_array[minind].c_color); /* put it there */
   return;                             /* all done */
-}
+ }
 
 static void c300_color_to_rgb(char *c_color, XColor *rgb_space) {
   int rc;
-  rc=XParseColor(save_dpy, PictureCMap, c_color, rgb_space);
+  rc=XParseColor(PictureSaveDisplay, PictureCMap, c_color, rgb_space);
   if (rc==0) {
     fprintf(stderr,"color_to_rgb: can't parse color %s, rc %d\n", c_color, rc);
     return;
