@@ -7,6 +7,21 @@
 #include <X11/Intrinsic.h>              /* needed for xpm.h and Pixel defn */
 #include <ctype.h>
 
+/* Allow GCC extensions to work, if you have GCC */
+
+#ifndef __attribute__
+/* This feature is available in gcc versions 2.5 and later.  */
+# if __GNUC__ < 2 || (__GNUC__ == 2 && __GNUC_MINOR__ < 5) || __STRICT_ANSI__
+#  define __attribute__(x)
+# endif
+/* The __-protected variants of `format' and `printf' attributes
+   are accepted by gcc versions 2.6.4 (effectively 2.7) and later.  */
+# if __GNUC__ < 2 || (__GNUC__ == 2 && __GNUC_MINOR__ < 7)
+#  define __format__ format
+#  define __printf__ printf
+# endif
+#endif
+
 /***********************************************************************
  * Generic debugging
  ***********************************************************************/
@@ -22,7 +37,8 @@
                    f_db_print _x;}while(0)
 struct f_db_info { const char *filenm; unsigned long lineno; };
 extern struct f_db_info f_db_info;
-extern void f_db_print(const char *fmt, ...);
+extern void f_db_print(const char *fmt, ...)
+                       __attribute__ ((__format__ (__printf__, 1, 2)));
 #endif
 
 
@@ -49,6 +65,10 @@ int matchWildcards(char *pattern, char *string);
 #define IsBlockEnd(c,cs) (((c) == ']' && (cs) == '[') || ((c) == '}' && (cs) == '{') || ((c) == ')' && (cs) == '('))
 #define MAX_TOKEN_LENGTH 255
 
+char *SkipQuote(char *s, const char *qlong, const char *qstart,
+		const char *qend);
+char *GetQuotedString(char *sin, char **sout, const char *delims,
+		      const char *qlong, const char *qstart, const char *qend);
 char *PeekToken(const char *pstr);
 char *GetToken(char **pstr);
 int CmpToken(const char *pstr,char *tok);
