@@ -1,35 +1,17 @@
 /* FvwmForm is original work of Thomas Zuwei Feng.
- * 
+ *
  * Copyright Feb 1995, Thomas Zuwei Feng.  No guarantees or warantees are
  * provided or implied in any way whatsoever.  Use this program at your own
  * risk.  Permission to use, modify, and redistribute this program is hereby
  * given, provided that this copyright is kept intact.
-
- Attempting to find common module logic, marked by module
- it comes from, Ie. FvwmAnimate.
-
- prog_name -> MyName(+1)
- strncmp -> strnCASEcmp on config commands.
- myfprintf
- use table to parse, lots of strncmps, cmdlen+= and isspaces done in 1 place.
-
  */
 #include "config.h"
+
 #include "../../libs/fvwmlib.h"
 
 #include <stdio.h>
-#include <stdlib.h>
 #include <ctype.h>
-#include <X11/Xlib.h>
-#include <X11/X.h>
-#include <X11/Xutil.h>
-#include <X11/cursorfont.h>
-#define XK_MISCELLANY
-#include <X11/keysymdef.h>
-#if !defined(__bsdi__) && !defined(__FreeBSD__)
-#include <malloc.h>
-#endif
-#include <string.h>
+
 #include <sys/types.h>
 #include <sys/time.h>
 #include <fcntl.h>
@@ -37,8 +19,12 @@
 #include <sys/select.h>
 #endif
 
-#include <ModParse.h>                   /* for FindToken */
-
+#include <X11/Xlib.h>
+#include <X11/X.h>
+#include <X11/Xutil.h>
+#include <X11/cursorfont.h>
+#define XK_MISCELLANY
+#include <X11/keysymdef.h>
 
 void dummy () {
 }
@@ -126,8 +112,6 @@ typedef union _item {
   } button;
 } Item;
 
-Item *item;                             /* used during parse dje */
-Item *cur_sel, *cur_button;             /* parse dje */
 
 #define L_LEFT        1
 #define L_RIGHT       2
@@ -141,23 +125,10 @@ typedef struct _line {
   Item **items;             /* list of items */
 } Line;
 
-Line *cur_line;                         /* curr line in parse rtns dje */
-
-/* From FvwmAnimate start */
-static char *MyName;
-static int MyNameLen;
-/* here is the old double parens trick. */
-/* #define DEBUG */
-#ifdef DEBUG
-#define myfprintf(X) \
-  fprintf X;\
-  fflush (stderr);
-#else
-#define myfprintf(X)
-#endif
-/* From FvwmAnimate end */
 
 /* global variables */
+char *prog_name;           /* program name, e.g. FvwmForm */
+
 int fd_in;                 /* fd for Fvwm->Module packets */
 int fd_out;                /* fd for Module->Fvwm packets */
 int fd[2]; /* pipe pair */
@@ -277,294 +248,17 @@ int FontWidth (XFontStruct *xfs)
   return (xfs->per_char[0].width);
 }
 
-/* Command parsing section */
-
-/* FvwmAnimate++ type command table */
-typedef struct CommandTable {
-  char *name;
-  void (*function)(char *);
-} ct;
-static void ct_Back(char *);
-static void ct_Button(char *);
-static void ct_ButtonFont(char *);
-static void ct_Choice(char *);
-static void ct_Command(char *);
-static void ct_Font(char *);
-static void ct_Fore(char *);
-static void ct_GrabServer(char *);
-static void ct_Input(char *);
-static void ct_InputFont(char *);
-static void ct_ItemBack(char *);
-static void ct_ItemFore(char *);
-static void ct_Line(char *);
-static void ct_Position(char *);
-static void ct_Selection(char *);
-static void ct_Text(char *);
-static void ct_WarpPointer(char *);
-/* Must be in Alphabetic order (caseless) */
-static struct CommandTable ct_table[] = {
-  {"Back",ct_Back},
-  {"Button",ct_Button},
-  {"ButtonFont",ct_ButtonFont},
-  {"Choice",ct_Choice},
-  {"Command",ct_Command},
-  {"Font",ct_Font},
-  {"Fore",ct_Fore},
-  {"GrabServer",ct_GrabServer},
-  {"Input",ct_Input},
-  {"InputFont",ct_InputFont},
-  {"ItemBack",ct_ItemBack},
-  {"ItemFore",ct_ItemFore},
-  {"Line",ct_Line},
-  {"Position",ct_Position},
-  {"Selection",ct_Selection},
-  {"Text",ct_Text},
-  {"WarpPointer",ct_WarpPointer}
-};
-
-/* temp dje */
-int XCmpToken();
-
-  
-ParseConfigLine(char *buf) {
-  char *p;
-  struct CommandTable *e;
-  if (buf[strlen(buf)-1] == '\n') {     /* if line ends with newline */
-    buf[strlen(buf)-1] = '\0';	/* strip off \n */
-  }
-  /* This used to be case sensitive */
-  if (strncasecmp(buf, MyName, MyNameLen) != 0) {/* If its not for me */
-    return;
-  } /* Now I know its for me. */
-  p = buf+MyNameLen;                  /* jump to end of my name */
-  /* at this point we have recognized "*FvwmForm" */
-  e = FindToken(p,ct_table,struct CommandTable);
-  if (e == 0) {                       /* if no match */
-    fprintf(stderr,"%s: unknown command: %s\n",MyName+1,buf);
-    return;
-  }
-  p=p+strlen(e->name);                 /* skip over name */
-  while (isspace(*p)) p++;              /* skip whitespace */
-  e->function(p);                       /* call cmd processor */
-  return;
-} /* end function */
-
-
-  /* Macro to add an item to the current line */
-#define AddToLine(ITEM) \
-  { \
-    cur_line->items[cur_line->n++] = ITEM;\
-    cur_line->size_x += ITEM->header.size_x;\
-    if (cur_line->size_y < ITEM->header.size_y)\
-      cur_line->size_y = ITEM->header.size_y;\
-  }
-
-
-/* All the functions starting with "ct_" are called thru
-   their function pointers */
-static void ct_GrabServer(char *cp) {
-  grab_server = 1;
-}
-static void ct_WarpPointer(char *cp) {
-  warp_pointer = 1;
-}
-static void ct_Position(char *cp) {
-  geom = 1;
-  gx = atoi(cp);
-  while (!isspace(*cp)) cp++;
-  while (isspace(*cp)) cp++;
-  gy = atoi(cp);
-  myfprintf((fp_err, "Position @ (%d, %d)\n", gx, gy));
-}
-static void ct_Fore(char *cp) {
-  color_names[c_fore] = CopyNString(cp, 0);
-  fprintf(fp_err, "ColorFore: %s\n", color_names[c_fore]);
-}
-static void ct_Back(char *cp) {
-  color_names[c_back] = CopyNString(cp, 0);
-  fprintf(fp_err, "ColorBack: %s\n", color_names[c_back]);
-}
-static void ct_ItemFore(char *cp) {
-  color_names[c_itemfore] = CopyNString(cp, 0);
-  fprintf(fp_err, "ColorItemFore: %s\n", color_names[c_itemfore]);
-}
-static void ct_ItemBack(char *cp) {
-  color_names[c_itemback] = CopyNString(cp, 0);
-  fprintf(fp_err, "ColorItemBack: %s\n", color_names[c_itemback]);
-}
-static void ct_Font(char *cp) {
-  font_names[f_text] = CopyNString(cp, 0);
-  fprintf(fp_err, "Font: %s\n", font_names[f_text]);
-  xfs[f_text] = GetFontOrFixed(dpy, font_names[f_text]);
-  fonts[f_text] = xfs[f_text]->fid;
-}
-static void ct_ButtonFont(char *cp) {
-  font_names[f_button] = CopyNString(cp, 0);
-  fprintf(fp_err, "ButtonFont: %s\n", font_names[f_button]);
-  xfs[f_button] = GetFontOrFixed(dpy, font_names[f_button]);
-  fonts[f_button] = xfs[f_button]->fid;
-}
-static void ct_InputFont(char *cp) {
-  font_names[f_input] = CopyNString(cp, 0);
-  fprintf(fp_err, "InputFont: %s\n", font_names[f_input]);
-  xfs[f_input] = GetFontOrFixed(dpy, font_names[f_input]);
-  fonts[f_input] = xfs[f_input]->fid;
-}
-static void ct_Line(char *cp) {
-  cur_line = lines + n_lines++;
-  if (strncasecmp(cp, "left", 4) == 0)
-    cur_line->justify = L_LEFT;
-  else if (strncasecmp(cp, "right", 5) == 0)
-    cur_line->justify = L_RIGHT;
-  else if (strncasecmp(cp, "center", 6) == 0)
-    cur_line->justify = L_CENTER;
-  else
-    cur_line->justify = L_LEFTRIGHT;
-  cur_line->n = 0;
-  cur_line->items = (Item **)malloc(sizeof(Item *) * ITEMS_PER_LINE);
-}
-static void ct_Text(char *cp) {
-  /* syntax: *FFText "<text>" */
-  item = items + n_items++;
-  item->type = I_TEXT;
-  item->header.name = "";
-  if (*cp == '\"')
-    item->text.value = CopyQuotedString(++cp);
-  else
-    item->text.value = "";
-  item->text.n = strlen(item->text.value);
-  item->header.size_x = XTextWidth(xfs[f_text], item->text.value, 
-                                   item->text.n) + 2 * TEXT_SPC;
-  item->header.size_y = FontHeight(xfs[f_text]) + 2 * TEXT_SPC;
-  fprintf(fp_err, "Text \"%s\" [%d, %d]\n", item->text.value,
-          item->header.size_x, item->header.size_y);
-  AddToLine(item);
-}
-static void ct_Input(char *cp) {
-  int j;
-  /* syntax: *FFInput <name> <size> "<init_value>" */
-  item = items + n_items++;
-  item->type = I_INPUT;
-  item->header.name = CopySolidString(cp);
-  cp += strlen(item->header.name);
-  while (isspace(*cp)) cp++;
-  item->input.size = atoi(cp);
-  while (!isspace(*cp)) cp++;
-  while (isspace(*cp)) cp++;
-  if (*cp == '\"')
-    item->input.init_value = CopyQuotedString(++cp);
-  else
-    item->input.init_value = "";
-  item->input.blanks = (char *)malloc(item->input.size);
-  for (j = 0; j < item->input.size; j++)
-    item->input.blanks[j] = ' ';
-  item->input.buf = strlen(item->input.init_value) + 1;
-  item->input.value = (char *)malloc(item->input.buf);
-  item->header.size_x = FontWidth(xfs[f_input]) * item->input.size
-    + 2 * TEXT_SPC + 2 * BOX_SPC;
-  item->header.size_y = FontHeight(xfs[f_input]) + 3 * TEXT_SPC
-    + 2 * BOX_SPC;
-  fprintf(fp_err, "Input, %s, [%d], \"%s\"\n", item->header.name,
-          item->input.size, item->input.init_value);
-  AddToLine(item);
-}
-static void ct_Selection(char *cp) {
-  /* syntax: *FFSelection <name> single | multiple */
-  cur_sel = items + n_items++;
-  cur_sel->type = I_SELECT;
-  cur_sel->header.name = CopySolidString(cp);
-  cp += strlen(cur_sel->header.name);
-  while (isspace(*cp)) cp++;
-  if (strncasecmp(cp, "multiple", 8) == 0)
-    cur_sel->select.key = IS_MULTIPLE;
-  else
-    cur_sel->select.key = IS_SINGLE;
-  cur_sel->select.n = 0;
-  cur_sel->select.choices = 
-    (Item **)malloc(sizeof(Item *) * CHOICES_PER_SEL);
-}
-static void ct_Choice(char *cp) {
-  /* syntax: *FFChoice <name> <value> [on | _off_] ["<text>"] */
-  item = items + n_items++;
-  item->type = I_CHOICE;
-  item->header.name = CopySolidString(cp);
-  cp += strlen(item->header.name);
-  while (isspace(*cp)) cp++;
-  item->choice.value = CopySolidString(cp);
-  cp += strlen(item->choice.value);
-  while (isspace(*cp)) cp++;
-  if (strncasecmp(cp, "on", 2) == 0)
-    item->choice.init_on = 1;
-  else
-    item->choice.init_on = 0;
-  while (!isspace(*cp)) cp++;
-  while (isspace(*cp)) cp++;
-  if (*cp == '\"')
-    item->choice.text = CopyQuotedString(++cp);
-  else
-    item->choice.text = "";
-  item->choice.n = strlen(item->choice.text);
-  item->choice.sel = cur_sel;
-  cur_sel->select.choices[cur_sel->select.n++] = item;
-  item->header.size_y = FontHeight(xfs[f_text]) + 2 * TEXT_SPC;
-  item->header.size_x = FontHeight(xfs[f_text]) + 4 * TEXT_SPC +
-    XTextWidth(xfs[f_text], item->choice.text, item->choice.n);
-  fprintf(fp_err, "Choice %s, \"%s\", [%d, %d]\n", item->header.name,
-          item->choice.text, item->header.size_x, item->header.size_y);
-  AddToLine(item);
-}
-static void ct_Button(char *cp) {
-  /* syntax: *FFButton continue | restart | quit "<text>" */
-  item = items + n_items++;
-  item->type = I_BUTTON;
-  item->header.name = "";
-  if (strncasecmp(cp, "restart", 7) == 0)
-    item->button.key = IB_RESTART;
-  else if (strncasecmp(cp, "quit", 4) == 0)
-    item->button.key = IB_QUIT;
-  else
-    item->button.key = IB_CONTINUE;
-  while (!isspace(*cp)) cp++;
-  while (isspace(*cp)) cp++;
-  if (*cp == '\"') {
-    item->button.text = CopyQuotedString(++cp);
-    cp += strlen(item->button.text) + 1;
-    while (isspace(*cp)) cp++;
-  } else
-    item->button.text = "";
-  if (*cp == '^')
-    item->button.keypress = *(++cp) - '@';
-  else if (*cp == 'F')
-    item->button.keypress = 256 + atoi(++cp);
-  else
-    item->button.keypress = -1;
-  item->button.len = strlen(item->button.text);
-  item->button.n = 0;
-  item->button.commands = (char **)malloc(sizeof(char *) * MAX_ITEMS);
-  item->header.size_y = FontHeight(xfs[f_button]) + 2 * TEXT_SPC
-    + 2 * BOX_SPC;
-  item->header.size_x = 2 * TEXT_SPC + 2 * BOX_SPC
-    + XTextWidth(xfs[f_button], item->button.text, item->button.len);
-  AddToLine(item);
-  cur_button = item;
-}
-static void ct_Command(char *cp) {
-  /* syntax: *FFCommand <command> */
-  cur_button->button.commands[cur_button->button.n++] =
-    CopyNString(cp, 0);
-}
-
-/* End of ct_ routines */
-
-
-
 /* read the configuration file */
-static void ReadConfig ()
+void ReadConfig ()
 {
   FILE *fp, *fopen();
-  int i, j, l, extra;
+  int prog_name_len, i, j, l, extra;
   char *line_buf;
-  Line *line;
+  char *cp;
+  Line *cur_line, *line;
+  Item *item, *cur_sel, *cur_button;
+
+#define AddToLine(item) { cur_line->items[cur_line->n++] = item; cur_line->size_x += item->header.size_x; if (cur_line->size_y < item->header.size_y) cur_line->size_y = item->header.size_y; }
 
   n_items = 0;
   n_lines = 0;
@@ -587,10 +281,239 @@ static void ReadConfig ()
     GetFontOrFixed(dpy, "fixed");
   fonts[f_text] = fonts[f_input] = fonts[f_button] = xfs[f_text]->fid;
 
-  while (GetConfigLine(fd,&line_buf),line_buf) {
-    ParseConfigLine(line_buf);
-  } /* end parsing config, go to it. */
+  prog_name_len = strlen(prog_name);
 
+  while (GetConfigLine(fd,&line_buf),line_buf) {
+    cp = line_buf;
+    while (isspace(*cp)) cp++;  /* skip blanks */
+    if (*cp != '*') continue;
+    if (strncmp(++cp, prog_name, prog_name_len) != 0) continue;
+    cp += prog_name_len;
+    /* at this point we have recognized "*FvwmForm" */
+    if (strncmp(cp, "GrabServer", 10) == 0) {
+      grab_server = 1;
+      continue;
+    }
+    else if (strncmp(cp, "WarpPointer", 11) == 0) {
+      warp_pointer = 1;
+    }
+    else if (strncmp(cp, "Position", 8) == 0) {
+      cp += 8;
+      geom = 1;
+      while (isspace(*cp)) cp++;
+      gx = atoi(cp);
+      while (!isspace(*cp)) cp++;
+      while (isspace(*cp)) cp++;
+      gy = atoi(cp);
+      fprintf(fp_err, "Position @ (%d, %d)\n", gx, gy);
+      continue;
+    }
+    else if (strncmp(cp, "Fore", 4) == 0) {
+      cp += 4;
+      while (isspace(*cp)) cp++;
+      color_names[c_fore] = CopyNString(cp, 0);
+      fprintf(fp_err, "ColorFore: %s\n", color_names[c_fore]);
+      continue;
+    } else if (strncmp(cp, "Back", 4) == 0) {
+      cp += 4;
+      while (isspace(*cp)) cp++;
+      color_names[c_back] = CopyNString(cp, 0);
+      fprintf(fp_err, "ColorBack: %s\n", color_names[c_back]);
+      continue;
+    } else if (strncmp(cp, "ItemFore", 8) == 0) {
+      cp += 8;
+      while (isspace(*cp)) cp++;
+      color_names[c_itemfore] = CopyNString(cp, 0);
+      fprintf(fp_err, "ColorItemFore: %s\n", color_names[c_itemfore]);
+      continue;
+    } else if (strncmp(cp, "ItemBack", 8) == 0) {
+      cp += 8;
+      while (isspace(*cp)) cp++;
+      color_names[c_itemback] = CopyNString(cp, 0);
+      fprintf(fp_err, "ColorItemBack: %s\n", color_names[c_itemback]);
+      continue;
+    } else if (strncmp(cp, "Font", 4) == 0) {
+      cp += 4;
+      while (isspace(*cp)) cp++;
+      font_names[f_text] = CopyNString(cp, 0);
+      fprintf(fp_err, "Font: %s\n", font_names[f_text]);
+      xfs[f_text] = GetFontOrFixed(dpy, font_names[f_text]);
+      fonts[f_text] = xfs[f_text]->fid;
+      continue;
+    } else if (strncmp(cp, "ButtonFont", 10) == 0) {
+      cp += 10;
+      while (isspace(*cp)) cp++;
+      font_names[f_button] = CopyNString(cp, 0);
+      fprintf(fp_err, "ButtonFont: %s\n", font_names[f_button]);
+      xfs[f_button] = GetFontOrFixed(dpy, font_names[f_button]);
+      fonts[f_button] = xfs[f_button]->fid;
+      continue;
+    } else if (strncmp(cp, "InputFont", 9) == 0) {
+      cp += 9;
+      while (isspace(*cp)) cp++;
+      font_names[f_input] = CopyNString(cp, 0);
+      fprintf(fp_err, "InputFont: %s\n", font_names[f_input]);
+      xfs[f_input] = GetFontOrFixed(dpy, font_names[f_input]);
+      fonts[f_input] = xfs[f_input]->fid;
+      continue;
+    } else if (strncmp(cp, "Line", 4) == 0) {
+      cp += 4;
+      cur_line = lines + n_lines++;
+      while (isspace(*cp)) cp++;
+      if (strncmp(cp, "left", 4) == 0)
+	cur_line->justify = L_LEFT;
+      else if (strncmp(cp, "right", 5) == 0)
+	cur_line->justify = L_RIGHT;
+      else if (strncmp(cp, "center", 6) == 0)
+	cur_line->justify = L_CENTER;
+      else
+	cur_line->justify = L_LEFTRIGHT;
+      cur_line->n = 0;
+      cur_line->items = (Item **)malloc(sizeof(Item *) * ITEMS_PER_LINE);
+      continue;
+    } else if (strncmp(cp, "Text", 4) == 0) {
+/* syntax: *FFText "<text>" */
+      cp += 4;
+      item = items + n_items++;
+      item->type = I_TEXT;
+      item->header.name = "";
+      while (isspace(*cp)) cp++;
+      if (*cp == '\"')
+	item->text.value = CopyQuotedString(++cp);
+      else
+	item->text.value = "";
+      item->text.n = strlen(item->text.value);
+      item->header.size_x = XTextWidth(xfs[f_text], item->text.value,
+				     item->text.n) + 2 * TEXT_SPC;
+      item->header.size_y = FontHeight(xfs[f_text]) + 2 * TEXT_SPC;
+      fprintf(fp_err, "Text \"%s\" [%d, %d]\n", item->text.value,
+	     item->header.size_x, item->header.size_y);
+      AddToLine(item);
+      continue;
+    }
+    else if (strncmp(cp, "Input", 5) == 0) {
+/* syntax: *FFInput <name> <size> "<init_value>" */
+      cp += 5;
+      item = items + n_items++;
+      item->type = I_INPUT;
+      while (isspace(*cp)) cp++;
+      item->header.name = CopySolidString(cp);
+      cp += strlen(item->header.name);
+      while (isspace(*cp)) cp++;
+      item->input.size = atoi(cp);
+      while (!isspace(*cp)) cp++;
+      while (isspace(*cp)) cp++;
+      if (*cp == '\"')
+	item->input.init_value = CopyQuotedString(++cp);
+      else
+	item->input.init_value = "";
+      item->input.blanks = (char *)malloc(item->input.size);
+      for (j = 0; j < item->input.size; j++)
+	item->input.blanks[j] = ' ';
+      item->input.buf = strlen(item->input.init_value) + 1;
+      item->input.value = (char *)malloc(item->input.buf);
+      item->header.size_x = FontWidth(xfs[f_input]) * item->input.size
+	+ 2 * TEXT_SPC + 2 * BOX_SPC;
+      item->header.size_y = FontHeight(xfs[f_input]) + 3 * TEXT_SPC
+	+ 2 * BOX_SPC;
+      fprintf(fp_err, "Input, %s, [%d], \"%s\"\n", item->header.name,
+	      item->input.size, item->input.init_value);
+      AddToLine(item);
+    }
+    else if (strncmp(cp, "Selection", 9) == 0) {
+/* syntax: *FFSelection <name> single | multiple */
+      cp += 9;
+      cur_sel = items + n_items++;
+      cur_sel->type = I_SELECT;
+      while (isspace(*cp)) cp++;
+      cur_sel->header.name = CopySolidString(cp);
+      cp += strlen(cur_sel->header.name);
+      while (isspace(*cp)) cp++;
+      if (strncmp(cp, "multiple", 8) == 0)
+	cur_sel->select.key = IS_MULTIPLE;
+      else
+	cur_sel->select.key = IS_SINGLE;
+      cur_sel->select.n = 0;
+      cur_sel->select.choices =
+	(Item **)malloc(sizeof(Item *) * CHOICES_PER_SEL);
+      continue;
+    } else if (strncmp(cp, "Choice", 6) == 0) {
+/* syntax: *FFChoice <name> <value> [on | _off_] ["<text>"] */
+      cp += 6;
+      item = items + n_items++;
+      item->type = I_CHOICE;
+      while (isspace(*cp)) cp++;
+      item->header.name = CopySolidString(cp);
+      cp += strlen(item->header.name);
+      while (isspace(*cp)) cp++;
+      item->choice.value = CopySolidString(cp);
+      cp += strlen(item->choice.value);
+      while (isspace(*cp)) cp++;
+      if (strncmp(cp, "on", 2) == 0)
+	item->choice.init_on = 1;
+      else
+	item->choice.init_on = 0;
+      while (!isspace(*cp)) cp++;
+      while (isspace(*cp)) cp++;
+      if (*cp == '\"')
+	item->choice.text = CopyQuotedString(++cp);
+      else
+	item->choice.text = "";
+      item->choice.n = strlen(item->choice.text);
+      item->choice.sel = cur_sel;
+      cur_sel->select.choices[cur_sel->select.n++] = item;
+      item->header.size_y = FontHeight(xfs[f_text]) + 2 * TEXT_SPC;
+      item->header.size_x = FontHeight(xfs[f_text]) + 4 * TEXT_SPC +
+	XTextWidth(xfs[f_text], item->choice.text, item->choice.n);
+      fprintf(fp_err, "Choice %s, \"%s\", [%d, %d]\n", item->header.name,
+	     item->choice.text, item->header.size_x, item->header.size_y);
+      AddToLine(item);
+      continue;
+    } else if (strncmp(cp, "Button", 6) == 0) {
+/* syntax: *FFButton continue | restart | quit "<text>" */
+      cp += 6;
+      item = items + n_items++;
+      item->type = I_BUTTON;
+      item->header.name = "";
+      while (isspace(*cp)) cp++;
+      if (strncmp(cp, "restart", 7) == 0)
+	item->button.key = IB_RESTART;
+      else if (strncmp(cp, "quit", 4) == 0)
+	item->button.key = IB_QUIT;
+      else
+	item->button.key = IB_CONTINUE;
+      while (!isspace(*cp)) cp++;
+      while (isspace(*cp)) cp++;
+      if (*cp == '\"') {
+	item->button.text = CopyQuotedString(++cp);
+	cp += strlen(item->button.text) + 1;
+	while (isspace(*cp)) cp++;
+      } else
+	item->button.text = "";
+      if (*cp == '^')
+	item->button.keypress = *(++cp) - '@';
+      else if (*cp == 'F')
+	item->button.keypress = 256 + atoi(++cp);
+      else
+	item->button.keypress = -1;
+      item->button.len = strlen(item->button.text);
+      item->button.n = 0;
+      item->button.commands = (char **)malloc(sizeof(char *) * MAX_ITEMS);
+      item->header.size_y = FontHeight(xfs[f_button]) + 2 * TEXT_SPC
+	+ 2 * BOX_SPC;
+      item->header.size_x = 2 * TEXT_SPC + 2 * BOX_SPC
+	+ XTextWidth(xfs[f_button], item->button.text, item->button.len);
+      AddToLine(item);
+      cur_button = item;
+      continue;
+    } else if (strncmp(cp, "Command", 7) == 0) {
+/* syntax: *FFCommand <command> */
+      cp += 7;
+      while (isspace(*cp)) cp++;
+      cur_button->button.commands[cur_button->button.n++] =
+	CopyNString(cp, 0);
+    }
+  }  /* end of switch() */
   /* get the geometry right */
   max_width = 0;
   total_height = ITEM_VSPC;
@@ -725,9 +648,9 @@ void GetColors ()
 		     DoRed | DoGreen | DoBlue);
     XStoreNamedColor(dpy, d_cmap, color_names[c_back], colors[c_back],
 		     DoRed | DoGreen | DoBlue);
-    XStoreNamedColor(dpy, d_cmap, color_names[c_itemfore], 
+    XStoreNamedColor(dpy, d_cmap, color_names[c_itemfore],
 		     colors[c_itemfore], DoRed | DoGreen | DoBlue);
-    XStoreNamedColor(dpy, d_cmap, color_names[c_itemback], 
+    XStoreNamedColor(dpy, d_cmap, color_names[c_itemback],
 		     colors[c_itemback], DoRed | DoGreen | DoBlue);
     XParseColor(dpy, d_cmap, color_names[c_itemback], &xc_item);
     red = (int) xc_item.red ;
@@ -756,7 +679,7 @@ void GetColors ()
     xc_item.flags = DoRed | DoGreen | DoBlue;
     XStoreColor(dpy, d_cmap, &xc_item);
   }
-}    
+}
 
 /* reset all the values */
 void Restart ()
@@ -854,7 +777,7 @@ void RedrawItem (Item *item, int click)
 		       BOX_SPC + TEXT_SPC + xfs[f_input]->ascent,
 		       item->input.blanks, item->input.size - len);
     XDrawImageString(dpy, item->header.win, gc_input,
-		     BOX_SPC + TEXT_SPC, 
+		     BOX_SPC + TEXT_SPC,
 		     BOX_SPC + TEXT_SPC + xfs[f_input]->ascent,
 		     item->input.value + item->input.left, len);
     if (item == cur_text && !click) {
@@ -937,7 +860,7 @@ void RedrawItem (Item *item, int click)
     XDrawSegments(dpy, item->header.win, gc_button, xsegs, 4);
     XSetForeground(dpy, gc_button, colors[c_itemfore]);
     XDrawImageString(dpy, item->header.win, gc_button,
-		     BOX_SPC + TEXT_SPC, 
+		     BOX_SPC + TEXT_SPC,
 		     BOX_SPC + TEXT_SPC + xfs[f_button]->ascent,
 		     item->button.text, item->button.len);
     break;
@@ -1059,7 +982,7 @@ void ParseCommand (int dn, char *sp, char end, int *dn1, char **sp1)
       ;
   }
 }
-  
+
 /* execute a command */
 void DoCommand (Item *cmd)
 {
@@ -1084,7 +1007,7 @@ void DoCommand (Item *cmd)
     len = 1;
     write(fd_out, &len, sizeof(int));
   }
-  
+
   /* post-command */
   if (cmd->button.key == IB_QUIT) {
     if (grab_server)
@@ -1123,7 +1046,7 @@ void OpenWindows ()
   xcb.pixel = colors[c_itemback];
   XQueryColor(dpy, d_cmap, &xcb);
   XRecolorCursor(dpy, xc_ibeam, &xcf, &xcb);
-  
+
   /* the frame window first */
   if (geom) {
     if (gx >= 0)
@@ -1141,7 +1064,7 @@ void OpenWindows ()
   frame = XCreateSimpleWindow(dpy, root, x, y, max_width, total_height,
 			      0, BlackPixel(dpy, screen), colors[c_back]);
   XSelectInput(dpy, frame, KeyPressMask | ExposureMask);
-  XStoreName(dpy, frame, MyName+1);
+  XStoreName(dpy, frame, prog_name);
   XSetWMHints(dpy, frame, &wmh);
   sh.x = x, sh.y = y;
   sh.width = max_width, sh.height = total_height;
@@ -1172,7 +1095,7 @@ void OpenWindows ()
       XChangeWindowAttributes(dpy, item->header.win, CWCursor, &xswa);
       break;
     case I_CHOICE:
-      item->header.win = 
+      item->header.win =
 	XCreateSimpleWindow(dpy, frame,
 			    item->header.pos_x, item->header.pos_y,
 			    item->header.size_y, item->header.size_y,
@@ -1182,12 +1105,12 @@ void OpenWindows ()
       XChangeWindowAttributes(dpy, item->header.win, CWCursor, &xswa);
       break;
     case I_BUTTON:
-      item->header.win = 
+      item->header.win =
 	XCreateSimpleWindow(dpy, frame,
 			    item->header.pos_x, item->header.pos_y,
 			    item->header.size_x, item->header.size_y,
 			    0, colors[c_back], colors[c_itemback]);
-      XSelectInput(dpy, item->header.win, 
+      XSelectInput(dpy, item->header.win,
 		   ButtonPressMask | ExposureMask);
       xswa.cursor = xc_hand;
       XChangeWindowAttributes(dpy, item->header.win, CWCursor, &xswa);
@@ -1198,7 +1121,7 @@ void OpenWindows ()
   XMapRaised(dpy, frame);
   XMapSubwindows(dpy, frame);
   if (warp_pointer) {
-    XWarpPointer(dpy, None, frame, 0, 0, 0, 0, 
+    XWarpPointer(dpy, None, frame, 0, 0, 0, 0,
 		 max_width / 2, total_height - 1);
   }
   DoCommand(&def_button);
@@ -1235,7 +1158,7 @@ void ReadXServer ()
       case Expose:
 	RedrawFrame();
 	if (grab_server && !server_grabbed) {
-	  if (GrabSuccess == 
+	  if (GrabSuccess ==
 	      XGrabPointer(dpy, frame, True, 0, GrabModeAsync, GrabModeAsync,
 			   None, None, CurrentTime))
 	    server_grabbed = 1;
@@ -1322,7 +1245,7 @@ void ReadXServer ()
 	  if (rel_cursor < cur_text->input.n) {
 	    rel_cursor++;
 	    abs_cursor++;
-	    if (abs_cursor >= cur_text->input.size && 
+	    if (abs_cursor >= cur_text->input.size &&
 		rel_cursor < cur_text->input.n) {
 	      abs_cursor--;
 	      cur_text->input.left++;
@@ -1417,7 +1340,7 @@ void ReadXServer ()
 	  if (buf[0] >= ' ' && buf[0] < '\177') {  /* regular char */
 	    if (++(cur_text->input.n) >= cur_text->input.buf) {
 	      cur_text->input.buf += cur_text->input.size;
-	      cur_text->input.value = 
+	      cur_text->input.value =
 		(char *)realloc(cur_text->input.value,
 				cur_text->input.buf);
 	    }
@@ -1469,13 +1392,13 @@ void ReadXServer ()
 	    len = cur_text->input.size;
 	  else
 	    XDrawImageString(dpy, cur_text->header.win, gc_input,
-			     BOX_SPC + TEXT_SPC + 
+			     BOX_SPC + TEXT_SPC +
 			     FontWidth(xfs[f_input]) * len,
 			     BOX_SPC + TEXT_SPC + xfs[f_input]->ascent,
-			     cur_text->input.blanks, 
+			     cur_text->input.blanks,
 			     cur_text->input.size - len);
 	  XDrawImageString(dpy, cur_text->header.win, gc_input,
-			   BOX_SPC + TEXT_SPC, 
+			   BOX_SPC + TEXT_SPC,
 			   BOX_SPC + TEXT_SPC + xfs[f_input]->ascent,
 			   cur_text->input.value + cur_text->input.left, len);
 	  x = BOX_SPC + TEXT_SPC + FontWidth(xfs[f_input]) * abs_cursor - 1;
@@ -1501,7 +1424,7 @@ void ReadXServer ()
 	    old_item->input.o_cursor = rel_cursor;
 	    cur_text = item;
 	    RedrawItem(old_item, 1);
-	    abs_cursor = (event.xbutton.x - BOX_SPC - 
+	    abs_cursor = (event.xbutton.x - BOX_SPC -
 			  TEXT_SPC + FontWidth(xfs[f_input]) / 2)
 	      / FontWidth(xfs[f_input]);
 	    if (abs_cursor < 0)
@@ -1515,7 +1438,7 @@ void ReadXServer ()
 	      rel_cursor = item->input.n;
 	    if (rel_cursor > 0 && rel_cursor == item->input.left)
 	      item->input.left--;
-	    if (rel_cursor < item->input.n && 
+	    if (rel_cursor < item->input.n &&
 		rel_cursor == item->input.left + item->input.size)
 	      item->input.left++;
 	    abs_cursor = rel_cursor - item->input.left;
@@ -1526,7 +1449,7 @@ void ReadXServer ()
 	  if (item->type == I_BUTTON) {
 	    RedrawItem(item, 1);
 	    XGrabPointer(dpy, item->header.win, False, ButtonReleaseMask,
-			 GrabModeAsync, GrabModeAsync, 
+			 GrabModeAsync, GrabModeAsync,
 			 None, None, CurrentTime);
 	  }
 	  break;
@@ -1540,7 +1463,7 @@ void ReadXServer ()
 	    XUngrabPointer(dpy, CurrentTime);
 	    XFlush(dpy);
 	  }
-	  if (event.xbutton.x >= 0 && 
+	  if (event.xbutton.x >= 0 &&
 	      event.xbutton.x < item->header.size_x &&
 	      event.xbutton.y >= 0 &&
 	      event.xbutton.y < item->header.size_y) {
@@ -1572,14 +1495,14 @@ void MainLoop ()
     }
   }
 }
-    
+
 
 /* main procedure */
 main (int argc, char **argv)
 {
   FILE *fdopen();
   int i;
-  char *s;                              /* FvwmAnimate */
+
   buf = (char *)malloc(N);  /* some kludge */
 
 #ifdef DEBUG
@@ -1590,56 +1513,44 @@ main (int argc, char **argv)
   fp_err = fdopen(fd_err, "w");
 #endif
 
-  /* From FvwmAnimate start */
-  /* Save our program  name - for error events */
-  if ((s=strrchr(argv[0], '/')))	/* strip path */
-    s++;
-  else				/* no slash */
-    s = argv[0];
-  if(argc==7)                         /* if override name */
-    s = argv[6];                      /* use arg as name */
-  MyNameLen=strlen(s)+1;		/* account for '*' */
-  MyName = safemalloc(MyNameLen+1);	/* account for \0 */
-  *MyName='*';
-  strcpy(MyName+1, s);		/* append name */
+  /* we get rid of the path from program name */
+  prog_name = argv[0];
+  i = strlen(prog_name);
+  while (prog_name[--i] != '/' && i > 0);
+  if (i > 0)
+    prog_name = prog_name + (i + 1);
+  fprintf(fp_err, "%s started...\n", prog_name);
 
-  myfprintf((stderr,"%s: Starting, argv[0] is %s, len %d\n",MyName+1,
-             argv[0],MyNameLen));
-
-  if ((argc != 6)&&(argc != 7)) {	/* Now MyName is defined */
-    fprintf(stderr,"%s Version "VERSION" should only be executed by fvwm!\n",
-            MyName+1);
-    /* FvwmForm debug from stdin? */
+  if (argc < 6) {
 #ifndef DEBUG
+    fprintf(fp_err, "%s must be started by Fvwm.\n", prog_name);
     exit(1);
 #else
     fd_out = 1;
     fd_in = 0;
     ref = None;
 #endif
-  }
-  /* From FvwmAnimate end */
-
-
-  /* Next part could be common to FvwmAnimate, but fd_out seems better
-     than Channel[] */
-  if (argc > 5) {
+  } else {
+    if(argc==7)
+      prog_name = argv[6];
     fd_out = atoi(argv[1]);
     fd_in = atoi(argv[2]);
     ref = strtol(argv[4], NULL, 16);
     if (ref == 0) ref = None;
-    myfprintf((fp_err, "ref == %d\n", ref));
+#ifdef DEBUG
+    fprintf(fp_err, "ref == %d\n", ref);
+#endif
   }
 
   fd[0]=fd_out;
   fd[1]=fd_in;
 
   if (!(dpy = XOpenDisplay(NULL))) {
-    fprintf(fp_err, "%s: can't open display.\n", MyName+1);
+    fprintf(fp_err, "%s: can't open display.\n", prog_name);
     exit(1);
   }
   fd_x = XConnectionNumber(dpy);
-  
+
   screen = DefaultScreen(dpy);
   root = RootWindow(dpy, screen);
   scr_depth = DefaultDepth(dpy, screen);
