@@ -2,7 +2,7 @@
 #include "FvwmIconMan.h"
 
 static char const rcsid[] =
-  "$Id: winlist.c,v 1.4 1998/11/06 17:53:52 domivogt Exp $";
+  "$Id: winlist.c,v 1.5 1998/11/15 18:00:14 dane Exp $";
 
 #define HASHTAB_SIZE 257
 
@@ -244,11 +244,17 @@ int check_win_complete (WinData *p)
     return 1;
 
   ConsoleDebug (WINLIST, "Checking completeness:\n");
-  ConsoleDebug (WINLIST, "\ttitlename: %s\n", p->titlename);
-  ConsoleDebug (WINLIST, "\ticonname: %s\n", p->iconname);
-  ConsoleDebug (WINLIST, "\tres: %s\n", p->resname);
-  ConsoleDebug (WINLIST, "\tclass: %s\n", p->classname);
-  ConsoleDebug (WINLIST, "\tdisplaystring: %s\n", p->display_string);
+  ConsoleDebug (WINLIST, "\ttitlename: %s\n",
+                (p->titlename ? p->titlename : "No Title name"));
+  ConsoleDebug (WINLIST, "\ticonname: %s\n",
+                (p->iconname ? p->iconname : "No Icon name"));
+  ConsoleDebug (WINLIST, "\tres: %s\n",
+                (p->resname ? p->resname : "No p->resname"));
+  ConsoleDebug (WINLIST, "\tclass: %s\n",
+                (p->classname ? p->classname : "No p->classname"));
+  ConsoleDebug (WINLIST, "\tdisplaystring: %s\n",
+                (p->display_string ? p->display_string :
+                 "No p->display_string"));
   ConsoleDebug (WINLIST, "\t(x, y): (%d, %d)\n", p->x, p->y);
   ConsoleDebug (WINLIST, "\tapp_id: 0x%x %d\n", p->app_id, p->app_id_set);
   ConsoleDebug (WINLIST, "\tdesknum: %d\n", p->desknum);
