@@ -23,6 +23,7 @@
 #include "../../libs/fvwmlib.h"
 #include "../../fvwm/fvwm.h"
 #include "FvwmPager.h"
+
 extern ScreenInfo Scr;
 extern Display *dpy;
 
@@ -481,9 +482,10 @@ void initialize_pager(void)
     /* if fore given in config set now, otherwise it'll be set later */
     gcv.foreground = (BalloonFore == NULL) ? 0 : GetColor(BalloonFore);
 
-    BalloonGC = XCreateGC(dpy, balloon.w,
-                          GCFont | GCForeground,
-                          &gcv);
+    BalloonGC = XCreateGC(dpy, balloon.w, GCFont | GCForeground, &gcv);
+
+    /* Make sure we don't get balloons initially with the Icon option. */
+    ShowBalloons = ShowPagerBalloons;
   } /* ShowBalloons */
 }
 
@@ -570,14 +572,14 @@ void DispatchEvent(XEvent *Event)
 		{
 		  XQueryPointer(dpy, Desks[i].w, &JunkRoot, &JunkChild,
 				&JunkX, &JunkY,&x, &y, &JunkMask);
-		  Scroll(i,x,y);
+		  Scroll(desk_w, desk_h, x, y, i);
 		}
 	    }
 	  if(Event->xany.window == icon_win)
 	    {
 	      XQueryPointer(dpy, icon_win, &JunkRoot, &JunkChild,
 			    &JunkX, &JunkY,&x, &y, &JunkMask);
-	      IconScroll(x,y);
+	      Scroll(icon_w, icon_h, x, y, -1);
 	    }
 	}
       break;
@@ -597,16 +599,23 @@ void DispatchEvent(XEvent *Event)
 	    {
 	      if(Event->xany.window == Desks[i].w)
 		{
+		  if (Scr.CurrentDesk != i + desk1)
+		    {
+		      SwitchToDeskAndPage(i,Event);
+		      Scr.CurrentDesk = i + desk1;
+		      Wait = 0;
+		    }
 		  XQueryPointer(dpy, Desks[i].w, &JunkRoot, &JunkChild,
 				&JunkX, &JunkY,&x, &y, &JunkMask);
-		  Scroll(i,x,y);
+		  Scroll(desk_w, desk_h, x, y, i);
+		  break;
 		}
 	    }
 	  if(Event->xany.window == icon_win)
 	    {
 	      XQueryPointer(dpy, icon_win, &JunkRoot, &JunkChild,
 			    &JunkX, &JunkY,&x, &y, &JunkMask);
-	      IconScroll(x,y);
+	      Scroll(icon_w, icon_h, x, y, -1);
 	    }
 	}
       break;
@@ -621,14 +630,14 @@ void DispatchEvent(XEvent *Event)
 		{
 		  XQueryPointer(dpy, Desks[i].w, &JunkRoot, &JunkChild,
 				    &JunkX, &JunkY,&x, &y, &JunkMask);
-		  Scroll(i,x,y);
+		  Scroll(desk_w, desk_h, x, y, i);
 		}
 	    }
 	  if(Event->xany.window == icon_win)
 	    {
 	      XQueryPointer(dpy, icon_win, &JunkRoot, &JunkChild,
 			    &JunkX, &JunkY,&x, &y, &JunkMask);
-	      IconScroll(x,y);
+	      Scroll(icon_w, icon_h, x, y, -1);
 	    }
 
 	}
@@ -975,27 +984,28 @@ void SwitchToDesk(int Desk)
 
 void SwitchToDeskAndPage(int Desk, XEvent *Event)
 {
+#ifndef NON_VIRTUAL
   char command[256];
 
   if (Scr.CurrentDesk != (Desk+desk1))
     {
-#ifndef NON_VIRTUAL
+      int vx, vy;
       SendInfo(fd,"Desk 0 10000\n",0);
-      sprintf(command,"GotoPage %d %d\n",
-	      Event->xbutton.x*(Scr.VxMax+Scr.MyDisplayWidth)/
-	      (desk_w*Scr.MyDisplayWidth),
-	      Event->xbutton.y*(Scr.VyMax+Scr.MyDisplayHeight)/
-	      (desk_h*Scr.MyDisplayHeight));
+      /* patch to let mouse button 3 change desks and do not cling to a page */
+      vx = Event->xbutton.x*(Scr.VxMax+Scr.MyDisplayWidth)/
+	(desk_w*Scr.MyDisplayWidth);
+      vy = Event->xbutton.y*(Scr.VyMax+Scr.MyDisplayHeight)/
+	(desk_h*Scr.MyDisplayHeight);
+      Scr.Vx = vx * Scr.MyDisplayWidth;
+      Scr.Vy = vy * Scr.MyDisplayHeight;
+      sprintf(command,"GotoPage %d %d\n", vx, vy);
       SendInfo(fd,command,0);
-
       sprintf(command,"Desk 0 %d\n",Desk+desk1);
       SendInfo(fd,command,0);
 
-#endif
     }
   else
     {
-#ifndef	NON_VIRTUAL
       sprintf(command,"GotoPage %d %d\n",
 	      Event->xbutton.x*(Scr.VxMax+Scr.MyDisplayWidth)/
 	      (desk_w*Scr.MyDisplayWidth),
@@ -1009,9 +1019,9 @@ void SwitchToDeskAndPage(int Desk, XEvent *Event)
 
 void IconSwitchPage(XEvent *Event)
 {
+#ifndef NON_VIRTUAL
   char command[256];
 
-#ifndef NON_VIRTUAL
   sprintf(command,"GotoPage %d %d\n",
 	  Event->xbutton.x*(Scr.VxMax+Scr.MyDisplayWidth)/
 	  (icon_w*Scr.MyDisplayWidth),
@@ -1298,14 +1308,16 @@ void Hilight(PagerWindow *t, int on)
   PictureIconWindow(t);
 }
 
-void Scroll(int Desk, int x, int y)
+/* Use Desk == -1 to scroll the icon window */
+void Scroll(int window_w, int window_h, int x, int y, int Desk)
 {
 #ifndef NON_VIRTUAL
   char command[256];
   int sx, sy;
   if(Wait == 0)
     {
-      if(Desk != Scr.CurrentDesk)
+      /* Desk < 0 means we want to scroll an icon window */
+      if(Desk >= 0 && Desk + desk1 != Scr.CurrentDesk)
 	{
 	  return;
 	}
@@ -1315,19 +1327,19 @@ void Scroll(int Desk, int x, int y)
       if(y < 0)
 	y = 0;
 
-      if(x > desk_w)
-	x = desk_w;
-      if(y > desk_h)
-	y = desk_h;
+      if(x > window_w)
+	x = window_w;
+      if(y > window_h)
+	y = window_h;
 
-      sx = (100*(x*(Scr.VxMax+Scr.MyDisplayWidth)/desk_w- Scr.Vx)) /
+      sx = (100*(x*(Scr.VxMax+Scr.MyDisplayWidth)/window_w- Scr.Vx)) /
 	Scr.MyDisplayWidth;
-      sy = (100*(y*(Scr.VyMax+Scr.MyDisplayHeight)/
-		   desk_h - Scr.Vy))/Scr.MyDisplayHeight;
-      if(sx > 100)sx = 100;
-      if(sx < -100)sx = -100;
-      if(sy < -100)sy = -100;
-      if(sy > 100)sy = 100;
+      sy = (100*(y*(Scr.VyMax+Scr.MyDisplayHeight)/window_h - Scr.Vy)) /
+	Scr.MyDisplayHeight;
+      /* Make sure we don't get stuck a few pixels fromt the top/left border.
+       * Since sx/sy are ints, values between 0 and 1 are rounded down. */
+      if(sx == 0 && x == 0 && Scr.Vx != 0) sx = -1;
+      if(sy == 0 && y == 0 && Scr.Vy != 0) sy = -1;
 
       sprintf(command,"Scroll %d %d\n",sx,sy);
       SendInfo(fd,command,0);
@@ -1336,41 +1348,6 @@ void Scroll(int Desk, int x, int y)
 #endif
 }
 
-
-void IconScroll(int x, int y)
-{
-#ifndef NON_VIRTUAL
-  char command[256];
-  int sx, sy;
-  if(Wait == 0)
-    {
-      if(x < 0)
-	x = 0;
-      if(y < 0)
-	y = 0;
-
-      if(x > icon_w)
-	x = icon_w;
-      if(y > icon_h)
-	y = icon_h;
-
-      sx = (100*(x*(Scr.VxMax+Scr.MyDisplayWidth)/icon_w- Scr.Vx)) /
-	Scr.MyDisplayWidth;
-      sy = (100*(y*(Scr.VyMax+Scr.MyDisplayHeight)/
-		   icon_h - Scr.Vy))/Scr.MyDisplayHeight;
-      if(sx > 100)sx = 100;
-      if(sx < -100)sx = -100;
-      if(sy < -100)sy = -100;
-      if(sy > 100)sy = 100;
-
-      sprintf(command,"Scroll %d %d\n",sx,sy);
-      SendInfo(fd,command,0);
-      Wait = 1;
-    }
-#endif
-}
-
-
 void MoveWindow(XEvent *Event)
 {
   char command[100];
@@ -1473,7 +1450,7 @@ void MoveWindow(XEvent *Event)
 	  XMoveWindow(dpy,t->w,Scr.MyDisplayWidth+Scr.VxMax,
 		      Scr.MyDisplayHeight+Scr.VyMax);
 	  XSync(dpy,0);
-	  sprintf(command,"WindowsDesk %d", NewDesk);
+	  sprintf(command,"MoveToDesk 0 %d", NewDesk);
 	  SendInfo(fd,command,t->w);
 	  t->desk = NewDesk;
 	}
@@ -1553,7 +1530,7 @@ void MoveWindow(XEvent *Event)
 	    }
 	  else
 	    {
-	      sprintf(command,"WindowsDesk %d", NewDesk + desk1);
+	      sprintf(command,"MoveToDesk 0 %d", NewDesk + desk1);
 	      SendInfo(fd,command,t->w);
 	      t->desk = NewDesk + desk1;
 	    }
@@ -1936,7 +1913,10 @@ void MapBalloonWindow (XEvent *event)
   t = Start;
 
   while ( ! matched_window ) {
-    if ( t->PagerView == event->xcrossing.window ) {
+    if (t == NULL) {
+      return;
+    }
+    else if ( t->PagerView == event->xcrossing.window ) {
       view = t->PagerView;
       view_width = t->pager_view_width;
       view_height = t->pager_view_height;
@@ -1948,9 +1928,6 @@ void MapBalloonWindow (XEvent *event)
       view_height = t->icon_view_height;
       matched_window = 1;
     }
-    else if ( t == NULL ) {
-      return;
-    }
     else {
       t = t->next;
     }
@@ -1974,24 +1951,41 @@ void MapBalloonWindow (XEvent *event)
 
   /* balloon is a top-level window, therefore need to
      translate pager window coords to root window coords */
-  XTranslateCoordinates(dpy, view, Scr.Root,
-                        x, y,
-                        &window_changes.x, &window_changes.y,
-                        &dummy);
+  XTranslateCoordinates(dpy, view, Scr.Root, x, y,
+                        &window_changes.x, &window_changes.y, &dummy);
 
-  /* make sure balloon doesn't go off screen horizontally
+
+  /* make sure balloon doesn't go off screen
      (actually 2 pixels from edge rather than 0 just to be pretty :-) */
+
+  /* too close to left */
   if ( window_changes.x < 2 )
     window_changes.x = 2;
+
+  /* too close to right */
   else if ( window_changes.x + window_changes.width >
             Scr.MyDisplayWidth - (2 * balloon.border) - 2 )
     window_changes.x = Scr.MyDisplayWidth - window_changes.width -
       (2 * balloon.border) - 2;
 
+  /* too close to top ... make yoffset +ve */
+  if ( window_changes.y < 2 ) {
+    y = - balloon.yoffset + view_height;
+    XTranslateCoordinates(dpy, view, Scr.Root, x, y,
+			  &window_changes.x, &window_changes.y, &dummy);
+  }
 
-  XConfigureWindow(dpy, balloon.w,
-                   CWX | CWY | CWWidth,
-                   &window_changes);
+  /* too close to bottom ... make yoffset -ve */
+  else if ( window_changes.y + balloon.height >
+	    Scr.MyDisplayHeight - (2 * balloon.border) - 2 ) {
+    y = - balloon.yoffset - balloon.height - (2 * balloon.border);
+    XTranslateCoordinates(dpy, view, Scr.Root, x, y,
+			  &window_changes.x, &window_changes.y, &dummy);
+  }
+
+
+  /* make changes to window */
+  XConfigureWindow(dpy, balloon.w, CWX | CWY | CWWidth, &window_changes);
 
   /* if background not set in config make it match pager window */
   if ( BalloonBack == NULL )
