@@ -195,75 +195,6 @@ void CreateWindow(int x,int y, int w, int h)
   _XA_WM_COLORMAP_WINDOWS = XInternAtom (dpy, "WM_COLORMAP_WINDOWS", False);
  }
 
-
-
-
-
-
-
-/****************************************************************************
- *
- * This routine computes the shadow color from the background color
- *
- ****************************************************************************/
-Pixel GetShadow(Pixel background) 
-{
-  XColor bg_color;
-  XWindowAttributes attributes;
-  
-  XGetWindowAttributes(dpy,Root,&attributes);
-  
-  bg_color.pixel = background;
-  XQueryColor(dpy,attributes.colormap,&bg_color);
-  
-  bg_color.red = (unsigned short)((bg_color.red*50)/100);
-  bg_color.green = (unsigned short)((bg_color.green*50)/100);
-  bg_color.blue = (unsigned short)((bg_color.blue*50)/100);
-  
-  if(!XAllocColor(dpy,attributes.colormap,&bg_color))
-    nocolor("alloc shadow","");
-  
-  return bg_color.pixel;
-}
-
-/****************************************************************************
- *
- * This routine computes the hilight color from the background color
- *
- ****************************************************************************/
-Pixel GetHilite(Pixel background) 
-{
-  XColor bg_color, white_p;
-  XWindowAttributes attributes;
-  
-  XGetWindowAttributes(dpy,Root,&attributes);
-  
-  bg_color.pixel = background;
-  XQueryColor(dpy,attributes.colormap,&bg_color);
-
-  white_p.pixel = GetColor("white");
-  XQueryColor(dpy,attributes.colormap,&white_p);
-  
-#ifndef min
-#define min(a,b) (((a)<(b)) ? (a) : (b))
-#define max(a,b) (((a)>(b)) ? (a) : (b))
-#endif
-
-  bg_color.red = max((white_p.red/5), bg_color.red);
-  bg_color.green = max((white_p.green/5), bg_color.green);
-  bg_color.blue = max((white_p.blue/5), bg_color.blue);
-  
-  bg_color.red = min(white_p.red, (bg_color.red*140)/100);
-  bg_color.green = min(white_p.green, (bg_color.green*140)/100);
-  bg_color.blue = min(white_p.blue, (bg_color.blue*140)/100);
-  
-  if(!XAllocColor(dpy,attributes.colormap,&bg_color))
-    nocolor("alloc hilight","");
-  
-  return bg_color.pixel;
-}
-
-
 /****************************************************************************
  * 
  * Loads a single color
@@ -803,6 +734,8 @@ void GrabWindow(Window target)
 
   XTranslateCoordinates(dpy, target, Root, 0, 0, &x,&y, &Junk);
 
+  InitPictureCMap(dpy,Root); /* store the window cmap for GetShadow */
+
   CreateWindow(x,y,tw,th);
   XSetWindowBorderWidth(dpy,target,0);
   XReparentWindow(dpy,target, holder_win,0,0);
