@@ -1,4 +1,4 @@
-/* FvwmWinList Module for Fvwm. 
+/* FvwmWinList Module for Fvwm.
  *
  *  Copyright 1994,  Mike Finger (mfinger@mermaid.micro.umn.edu or
  *                               Mike_Finger@atk.com)
@@ -29,7 +29,7 @@
 */
 
 #define TRUE 1
-#define FALSE 
+#define FALSE
 
 #ifndef NO_CONSOLE
 #define NO_CONSOLE
@@ -138,7 +138,7 @@ int main(int argc, char **argv)
   s=strrchr(argv[0], '/');
   if (s != NULL)
     temp = s + 1;
-  
+
   /* Setup my name */
   Module = safemalloc(strlen(temp)+2);
   strcpy(Module,"*");
@@ -162,7 +162,7 @@ int main(int argc, char **argv)
   Fvwm_fd[0] = atoi(argv[1]);
   Fvwm_fd[1] = atoi(argv[2]);
 
-  signal (SIGPIPE, DeadPipe);  
+  signal (SIGPIPE, DeadPipe);
 
   /* Parse the config file */
   ParseConfig();
@@ -268,24 +268,8 @@ void ProcessMessage(unsigned long type,unsigned long *body)
   {
     case M_ADD_WINDOW:
     case M_CONFIGURE_WINDOW:
-      if (body[0] == win)
+      if ((i = FindItem(&windows,body[0]))!=-1)
       {
-        /* gross hack for anchored resizes, should be able to call XResizeWindow
-           and have fvwm move the window correctly w.r.t. the gravity.  Until this
-           is so this program has to do its own gravity management. */
-        /* what happens here is that fvwm sends the size and position of
-           FvwmWinLists' parent, this has to compensate for the frame
-           to get the position of the WinList window so that when XMoveResize
-           is called the window doesn't creep */
-        /* if fvwm is fixed to handle windows resizing themselves then this
-           whole section can be deleted. */
-        win_title=(int)body[9];
-        win_border=(int)body[10];
-        win_x = (int)body[3] + win_border;
-        win_y = (int)body[4] + win_border + win_title;
-      }
-      if ((i = FindItem(&windows,body[0]))!=-1) 
-      { 
 	if(UpdateItemDesk(&windows, i, body[7]) > 0)
         {
           AdjustWindow();
@@ -326,7 +310,7 @@ void ProcessMessage(unsigned long type,unsigned long *body)
 
     case M_WINDOW_NAME:
     case M_ICON_NAME:
-      if ((type==M_ICON_NAME && !UseIconNames) || 
+      if ((type==M_ICON_NAME && !UseIconNames) ||
           (type==M_WINDOW_NAME && UseIconNames)) break;
       if ((i=UpdateItemName(&windows,body[0],(char *)&body[3]))==-1) break;
       string=(char *)&body[3];
@@ -357,27 +341,27 @@ void ProcessMessage(unsigned long type,unsigned long *body)
       free(name);
       break;
     case M_FOCUS_CHANGE:
-    if ((i=FindItem(&windows,body[0]))!=-1)
-    {
-      flags=ItemFlags(&windows,body[0]);
-      UpdateItemFlags(&windows,body[0],flags);
-      RadioButton(&buttons,i);
+      if ((i=FindItem(&windows,body[0]))!=-1)
+      {
+        flags=ItemFlags(&windows,body[0]);
+        UpdateItemFlags(&windows,body[0],flags);
+        RadioButton(&buttons,i);
+      }
+      else
+        RadioButton(&buttons,-1);
       redraw = 1;
-    }
-    break;
-
       break;
     case M_END_WINDOWLIST:
       if (!WindowIsUp) MakeMeWindow();
-      redraw=1;
+      redraw = 1;
       break;
     case M_NEW_DESK:
-	CurrentDesk = body[0];
-	if(ShowCurrentDesk)
-	{
-	  AdjustWindow();
-	  RedrawWindow(1);
-        }
+      CurrentDesk = body[0];
+      if(ShowCurrentDesk)
+      {
+        AdjustWindow();
+        RedrawWindow(1);
+      }
       break;
     case M_NEW_PAGE:
       break;
@@ -387,7 +371,7 @@ void ProcessMessage(unsigned long type,unsigned long *body)
 }
 
 /******************************************************************************
-  SendFvwmPipe - Send a message back to fvwm 
+  SendFvwmPipe - Send a message back to fvwm
     Based on SendInfo() from FvwmIdent:
       Copyright 1994, Robert Nation and Nobutaka Suzuki.
 ******************************************************************************/
@@ -425,7 +409,7 @@ void SendFvwmPipe(char *message,unsigned long window)
 }
 
 /***********************************************************************
-  Detected a broken pipe - time to exit 
+  Detected a broken pipe - time to exit
     Based on DeadPipe() from FvwmIdent:
       Copyright 1994, Robert Nation and Nobutaka Suzuki.
  **********************************************************************/
@@ -506,9 +490,9 @@ void ParseConfig()
   char *tline;
 
   GetConfigLine(Fvwm_fd,&tline);
-  while(tline != (char *)0) 
+  while(tline != (char *)0)
     {
-      if(strlen(tline)>1) 
+      if(strlen(tline)>1)
 	{
 	  if(strncasecmp(tline, CatString3(Module, "Font",""),Clength+4)==0)
 	    CopyString(&font_string,&tline[Clength+4]);
@@ -658,15 +642,44 @@ void LoopOnEvents()
         break;
     }
   }
-} 
+}
+
+
+/******************************************************************************
+  find_frame_window - looks for ancestor that is a child of the root
+  Cribbed from FvwmIconMan/x.c - maybe should be in a library
+  Returns the root-child and fills in off_x, off_y to give offset
+******************************************************************************/
+Window find_frame_window (Window win, int *off_x, int *off_y)
+{
+  Window root, parent, *junkw;
+  int junki;
+  XWindowAttributes attr;
+
+  while (1) {
+    XQueryTree (dpy, win, &root, &parent, &junkw, &junki);
+    if (junkw)
+      XFree (junkw);
+    if (parent == root)
+      break;
+    XGetWindowAttributes (dpy, win, &attr);
+    *off_x += attr.x + attr.border_width;
+    *off_y += attr.y + attr.border_width;
+    win = parent;
+  }
+
+  return win;
+}
 
 /******************************************************************************
   AdjustWindow - Resize the window according to maxwidth by number of buttons
 ******************************************************************************/
 void AdjustWindow()
 {
-  int new_width=0,new_height=0,tw,i,total;
+  int new_width=0,new_height=0,tw,i,total,off_x,off_y;
   char *temp;
+  Window frame;
+  XWindowAttributes win_attr, frame_attr;
 
   total = ItemCountD(&windows );
   if (!total)
@@ -686,7 +699,9 @@ void AdjustWindow()
 	tw=10+XTextWidth(ButtonFont,temp,strlen(temp));
 	tw+=XTextWidth(ButtonFont,"()",2);
 
+#ifdef MINI_ICONS
 	tw+=14; /* for title icon */ /* Magic Number ? */
+#endif
 
 	new_width=max(new_width,tw);
     }
@@ -697,18 +712,22 @@ void AdjustWindow()
   if (WindowIsUp && (new_height!=win_height  || new_width!=win_width))
   {
     if (Anchor)
-    /* if fvwm is fixed to handle windows with gravity resizing themselves
-       this will be redundant, just a XResizeWindow will work. How to handle
-       NoAnchor in that case is left as an exercise for the reader. */
     {
-      if (win_grav==SouthEastGravity || win_grav==NorthEastGravity)
-        win_x-=(new_width-win_width);
+      off_x = off_y = 0;
+      MyXGrabServer(dpy);
+      frame = find_frame_window(win, &off_x, &off_y);
+      XGetWindowAttributes(dpy, frame, &frame_attr);
+      XGetWindowAttributes(dpy, win, &win_attr);
+      win_x = frame_attr.x + frame_attr.border_width + off_x;
+      win_y = frame_attr.y + frame_attr.border_width + off_y;
 
-      if (win_grav==SouthEastGravity || win_grav==SouthWestGravity)
-        win_y-=(new_height-win_height);
+      if (win_grav == SouthEastGravity || win_grav == NorthEastGravity)
+        win_x += win_attr.width - new_width;
+      if (win_grav == SouthEastGravity || win_grav == SouthWestGravity)
+        win_y += win_attr.height - new_height;
 
       XMoveResizeWindow(dpy, win, win_x, win_y, new_width, new_height);
-
+      MyXUngrabServer(dpy);
     }
     else
       XResizeWindow(dpy, win, new_width, new_height);
@@ -770,7 +789,7 @@ void MakeMeWindow(void)
   Window dummyroot, dummychild;
   int i;
 
-  
+
   if ((count = ItemCountD(&windows))==0 && Transient) ShutMeDown(0);
   AdjustWindow();
 
@@ -839,7 +858,7 @@ void MakeMeWindow(void)
 
   wm_del_win=XInternAtom(dpy,"WM_DELETE_WINDOW",False);
   XSetWMProtocols(dpy,win,&wm_del_win,1);
-  
+
   XSetWMNormalHints(dpy,win,&hints);
 
   if (!Transient)
@@ -867,9 +886,9 @@ void MakeMeWindow(void)
     gcmask=GCForeground|GCBackground|GCFont;
     graph[i]=XCreateGC(dpy,Root,gcmask,&gcval);
 
-    if(d_depth < 2) 
+    if(d_depth < 2)
       gcval.foreground=GetShadow(fore[i]);
-    else 
+    else
       gcval.foreground=GetShadow(back[i]);
     gcval.background=back[i];
     gcmask=GCForeground|GCBackground;
@@ -884,7 +903,7 @@ void MakeMeWindow(void)
     gcmask=GCForeground;
     background[i]=XCreateGC(dpy,Root,gcmask,&gcval);
   }
-  
+
   XSelectInput(dpy,win,(ExposureMask | KeyPressMask));
 
   ChangeWindowName(&Module[1]);
@@ -968,10 +987,10 @@ XTextProperty name;
 
 /**************************************************************************
  *
- * Sets mwm hints 
+ * Sets mwm hints
  *
  *************************************************************************/
-/* 
+/*
  *  Now, if we (hopefully) have MWW - compatible window manager ,
  *  say, mwm, ncdwm, or else, we will set useful decoration style.
  *  Never check for MWM_RUNNING property.May be considered bad.
@@ -983,7 +1002,7 @@ PropMwmHints prop;
 
   if (MwmAtom==None)
     {
-      MwmAtom=XInternAtom(dpy,"_MOTIF_WM_HINTS",False);  
+      MwmAtom=XInternAtom(dpy,"_MOTIF_WM_HINTS",False);
     }
   if (MwmAtom!=None)
     {
@@ -992,7 +1011,7 @@ PropMwmHints prop;
       prop.functions = funcs;
       prop.inputMode = input;
       prop.flags = MWM_HINTS_DECORATIONS| MWM_HINTS_FUNCTIONS | MWM_HINTS_INPUT_MODE;
-      
+
       /* HOP - LA! */
       XChangeProperty (dpy,win,
 		       MwmAtom, MwmAtom,
