@@ -1,4 +1,5 @@
-#include "../../libs/fvwmlib.h"       
+#include "fvwmlib.h"       
+
 /* FvwmWinList Module for Fvwm. 
  *
  *  Copyright 1994,  Mike Finger (mfinger@mermaid.micro.umn.edu or
@@ -19,13 +20,13 @@
  * own risk. Permission to use this program for any purpose is given,
  * as long as the copyright is kept intact. */
 
-#define STICKY         1 /* Does window stick to glass? */
-#define ONTOP          2 /* does window stay on top */
-#define BORDER         4 /* Is this decorated with border*/
-#define TITLE          8 /* Is this decorated with title */
-#define ICONIFIED     32 /* is it an icon now? */
-#define TRANSIENT     64 /* is it a transient window? */
-#define WINDOWLISTSKIP         262144
+#define STICKY         (1<<2) /* Does window stick to glass? */
+#define ONTOP          (1<<1) /* does window stay on top */
+#define BORDER         (1<<13) /* Is this decorated with border*/
+#define TITLE          (1<<14) /* Is this decorated with title */
+#define ICONIFIED      (1<<16) /* is it an icon now? */
+#define TRANSIENT      (1<<17) /* is it a transient window? */
+#define WINDOWLISTSKIP   (1<<3)
 
 /* Motif  window hints */
 typedef struct
@@ -69,6 +70,10 @@ typedef PropMotifWmHints        PropMwmHints;
 #define PROP_MOTIF_WM_HINTS_ELEMENTS  4
 #define PROP_MWM_HINTS_ELEMENTS       PROP_MOTIF_WM_HINTS_ELEMENTS
 
+/* default values for configuration parameters */
+#define DEFMAXWIDTH 10000
+#define DEFMINWIDTH 0
+
 /*************************************************************************
   Subroutine Prototypes
 **************************************************************************/
@@ -84,7 +89,7 @@ void StartMeUp(void);
 void ShutMeDown(int exitstat);
 void ConsoleMessage(char *fmt,...);
 int OpenConsole(void);
-void ParseConfig(char *file);
+void ParseConfig(void);
 void LoopOnEvents(void);
 void AdjustWindow(void);
 char *makename(char *string,long flags);
@@ -96,12 +101,4 @@ void PrintSkipList(void);
 void FvwmNameMessage(long *body);
 void SetMwmHints(unsigned int value,unsigned int funcs,unsigned int input);
 
-int matchWildcards(char *pattern, char *string);
-
-#ifdef BROKEN_SUN_HEADERS
-#include "../../fvwm/sun_headers.h"
-#endif
-
-#ifdef NEEDS_ALPHA_HEADER
-#include "../../fvwm/alpha_header.h"
-#endif /* NEEDS_ALPHA_HEADER */
+XErrorHandler ErrorHandler(Display *d, XErrorEvent *event);
